@@ -22,7 +22,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECC14n20010315.cpp 464121 2006-10-15 05:15:59Z blautenb $
+ * $Id: XSECC14n20010315.cpp 569036 2007-08-23 15:18:39Z scantor $
  *
  */
 
@@ -387,12 +387,20 @@ XSECC14n20010315::~XSECC14n20010315() {
 
 	for (int i = 0; i < size; ++i) {
 
-		delete [] m_exclNSList[i];
+		free(m_exclNSList[i]);
 
 	}
 
 	m_exclNSList.clear();
 
+    while (mp_attributes != NULL) {
+
+        mp_currentAttribute = mp_attributes->next;
+        delete mp_attributes;
+        mp_attributes = mp_currentAttribute;
+    }
+
+    mp_attributes = mp_currentAttribute = mp_firstNonNsAttribute = NULL;
 }
 
 // --------------------------------------------------------------------------------
@@ -822,6 +830,12 @@ bool XSECC14n20010315::checkRenderNameSpaceNode(DOMNode *e, DOMNode *a) {
 	if (strEquals(a->getNodeName(), "xmlns") && strEquals(a->getNodeValue(), ""))
 		return false;
 
+	// If using a namespace stack, then we need to check whether the current node is in the nodeset
+	// Only really necessary for envelope txfms in boundary conditions
+
+	if (m_useNamespaceStack && m_XPathSelection && !m_XPathMap.hasNode(e))
+		return false;
+
 	// Otherwise, of node is at base of selected document, then print
 	if (e == mp_firstElementNode)
 		return true;
@@ -834,27 +848,27 @@ bool XSECC14n20010315::checkRenderNameSpaceNode(DOMNode *e, DOMNode *a) {
 		parent = e->getParentNode();
 		while (parent != NULL) {
 
-			DOMNamedNodeMap *pmap = parent->getAttributes();
-			DOMNode *pns;
-			if (pmap)
-				pns = pmap->getNamedItem(a->getNodeName());
-			else
-				pns = NULL;
-
-			if (pns != NULL) {
-
-				// Note we don't check XPath inclusion, as we shouldn't be
-				// using the namespace stack for XPath expressions
-
-				if (strEquals(pns->getNodeValue(), a->getNodeValue()))
-					return false;
+			if (!m_XPathSelection || m_XPathMap.hasNode(parent)) {
+				DOMNamedNodeMap *pmap = parent->getAttributes();
+				DOMNode *pns;
+				if (pmap)
+					pns = pmap->getNamedItem(a->getNodeName());
 				else
-					return true;		// Was defined but differently
+					pns = NULL;
+
+				if (pns != NULL) {
+
+					// Note we don't check XPath inclusion, as we shouldn't be
+					// using the namespace stack for XPath expressions
+
+					if (strEquals(pns->getNodeValue(), a->getNodeValue()))
+						return false;
+					else
+						return true;		// Was defined but differently
+				}
 			}
 			parent = parent->getParentNode();
-
 		}
-
 		// Obviously we haven't found it!
 		return true;
 	}
