@@ -20,7 +20,7 @@
  * XSECAlgorithmHandlerDefault := Interface class to define handling of
  *								  default encryption algorithms
  *
- * $Id: DSIGAlgorithmHandlerDefault.cpp 450745 2006-09-28 07:52:38Z blautenb $
+ * $Id: DSIGAlgorithmHandlerDefault.cpp 575854 2007-09-15 02:08:41Z scantor $
  *
  */
 
@@ -35,7 +35,7 @@
 #include <xsec/framework/XSECError.hpp>
 #include <xsec/utils/XSECDOMUtils.hpp>
 
-#include "DSIGAlgorithmHandlerDefault.hpp"
+#include <xsec/dsig/DSIGAlgorithmHandlerDefault.hpp>
 
 #include <xercesc/dom/DOM.hpp>
 #include <xercesc/util/Janitor.hpp>
