@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: DSIGKeyInfoList.cpp 464121 2006-10-15 05:15:59Z blautenb $
+ * $Id: DSIGKeyInfoList.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -75,7 +75,7 @@ DSIGKeyInfo * DSIGKeyInfoList::removeKeyInfo(size_type index) {
 
 }
 
-size_t DSIGKeyInfoList::getSize() {
+size_t DSIGKeyInfoList::getSize() const {
 
 	return m_keyInfoList.size();
 
@@ -91,6 +91,15 @@ DSIGKeyInfo * DSIGKeyInfoList::item(size_type index) {
 
 }
 
+const DSIGKeyInfo * DSIGKeyInfoList::item(size_type index) const {
+
+	if (index < m_keyInfoList.size())
+		return m_keyInfoList[index];
+	
+	return NULL;
+
+}
+
 void DSIGKeyInfoList::empty() {
 
 	size_type i, s;
@@ -103,7 +112,7 @@ void DSIGKeyInfoList::empty() {
 
 }
 
-bool DSIGKeyInfoList::isEmpty() {
+bool DSIGKeyInfoList::isEmpty() const {
 
 		return (m_keyInfoList.size() == 0);
 
