@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: DSIGKeyInfoSPKIData.cpp 351208 2005-02-03 12:56:37Z milan $
+ * $Id: DSIGKeyInfoSPKIData.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -126,13 +126,13 @@ void DSIGKeyInfoSPKIData::load(void) {
 
 }
 
-unsigned int DSIGKeyInfoSPKIData::getSexpSize(void) {
+unsigned int DSIGKeyInfoSPKIData::getSexpSize(void) const {
 
 	return (unsigned int) m_sexpList.size();
 
 }
 
-const XMLCh * DSIGKeyInfoSPKIData::getSexp(unsigned int index) {
+const XMLCh * DSIGKeyInfoSPKIData::getSexp(unsigned int index) const {
 
 	if (index >= m_sexpList.size()) {
 
