@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoHashHMAC.cpp 351396 2005-07-25 10:38:45Z milan $
+ * $Id: OpenSSLCryptoHashHMAC.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -191,7 +191,7 @@ unsigned int OpenSSLCryptoHashHMAC::finish(unsigned char * hash,
 
 // Get information
 
-XSECCryptoHash::HashType OpenSSLCryptoHashHMAC::getHashType(void) {
+XSECCryptoHash::HashType OpenSSLCryptoHashHMAC::getHashType(void) const {
 
 	return m_hashType;			// This could be any kind of hash
 
