@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoKeyDSA.cpp 351371 2005-06-10 08:02:30Z blautenb $
+ * $Id: OpenSSLCryptoKeyDSA.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 #include <xsec/framework/XSECDefs.hpp>
@@ -55,7 +55,7 @@ OpenSSLCryptoKeyDSA::~OpenSSLCryptoKeyDSA() {
 
 // Generic key functions
 
-XSECCryptoKey::KeyType OpenSSLCryptoKeyDSA::getKeyType() {
+XSECCryptoKey::KeyType OpenSSLCryptoKeyDSA::getKeyType() const {
 
 	// Find out what we have
 	if (mp_dsaKey == NULL)
@@ -327,7 +327,7 @@ unsigned int OpenSSLCryptoKeyDSA::signBase64Signature(unsigned char * hashBuf,
 
 
 
-XSECCryptoKey * OpenSSLCryptoKeyDSA::clone() {
+XSECCryptoKey * OpenSSLCryptoKeyDSA::clone() const {
 
 	OpenSSLCryptoKeyDSA * ret;
 
