@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoKeyDSA.hpp 409949 2006-05-28 11:49:50Z blautenb $
+ * $Id: OpenSSLCryptoKeyDSA.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -74,19 +74,19 @@ public :
 	 * public key, private key or a key pair
 	 */
 
-	virtual XSECCryptoKey::KeyType getKeyType();
+	virtual XSECCryptoKey::KeyType getKeyType() const;
 
 	/**
 	 *\brief Return the OpenSSL string identifier
 	 */
 
-	virtual const XMLCh * getProviderName() {return DSIGConstants::s_unicodeStrPROVOpenSSL;}
+	virtual const XMLCh * getProviderName() const {return DSIGConstants::s_unicodeStrPROVOpenSSL;}
 
 	/**
 	 * \brief Replicate key
 	 */
 
-	virtual XSECCryptoKey * clone();
+	virtual XSECCryptoKey * clone() const;
 
 	//@}
 
@@ -205,6 +205,12 @@ public :
 
 	DSA * getOpenSSLDSA(void) {return mp_dsaKey;}
 
+    /**
+	 * \brief Get OpenSSL DSA structure
+	 */
+
+	const DSA * getOpenSSLDSA(void) const {return mp_dsaKey;}
+
 	//@}
 	//@}
 
