@@ -22,7 +22,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoSymmetricKey.cpp 395833 2006-04-21 10:21:57Z blautenb $
+ * $Id: OpenSSLCryptoSymmetricKey.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -68,19 +68,19 @@ OpenSSLCryptoSymmetricKey::~OpenSSLCryptoSymmetricKey() {
 //           Basic Key interface methods
 // --------------------------------------------------------------------------------
 
-XSECCryptoSymmetricKey::SymmetricKeyType OpenSSLCryptoSymmetricKey::getSymmetricKeyType() {
+XSECCryptoSymmetricKey::SymmetricKeyType OpenSSLCryptoSymmetricKey::getSymmetricKeyType() const {
 
 	return m_keyType;
 
 }
 
-const XMLCh * OpenSSLCryptoSymmetricKey::getProviderName() {
+const XMLCh * OpenSSLCryptoSymmetricKey::getProviderName() const {
 
 	return DSIGConstants::s_unicodeStrPROVOpenSSL;
 
 }
 
-XSECCryptoKey * OpenSSLCryptoSymmetricKey::clone() {
+XSECCryptoKey * OpenSSLCryptoSymmetricKey::clone() const {
 
 	OpenSSLCryptoSymmetricKey * ret;
 
