@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: WinCAPICryptoHashHMAC.cpp 369748 2006-01-17 10:51:13Z blautenb $
+ * $Id: WinCAPICryptoHashHMAC.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -407,7 +407,7 @@ unsigned int WinCAPICryptoHashHMAC::finish(unsigned char * hash,
 
 // Get information
 
-XSECCryptoHash::HashType WinCAPICryptoHashHMAC::getHashType(void) {
+XSECCryptoHash::HashType WinCAPICryptoHashHMAC::getHashType(void) const {
 
 	return m_hashType;			// This could be any kind of hash
 
