@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: WinCAPICryptoKeyHMAC.hpp 369191 2006-01-15 09:14:43Z blautenb $
+ * $Id: WinCAPICryptoKeyHMAC.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -89,19 +89,19 @@ public :
 	 * public key, private key or a key pair
 	 */
 
-	virtual XSECCryptoKey::KeyType getKeyType() {return KEY_HMAC;}
+	virtual XSECCryptoKey::KeyType getKeyType() const {return KEY_HMAC;}
 	
 	/**
 	 * \brief Replicate key
 	 */
 
-	virtual XSECCryptoKey * clone();
+	virtual XSECCryptoKey * clone() const ;
 
 	/**
 	 * \brief Return the WinCAPI string identifier
 	 */
 
-	virtual const XMLCh * getProviderName() {return DSIGConstants::s_unicodeStrPROVWinCAPI;}
+	virtual const XMLCh * getProviderName() const {return DSIGConstants::s_unicodeStrPROVWinCAPI;}
 
 	//@}
 
@@ -132,7 +132,7 @@ public :
 	 * @returns number of bytes copied in
 	 */
 
-	virtual unsigned int getKey(safeBuffer &outBuf);
+	virtual unsigned int getKey(safeBuffer &outBuf) const;
 
 	//@}
 
@@ -160,7 +160,7 @@ public :
 	 * @returns The key to use or 0 if this object does not hold one
 	 */
 
-	HCRYPTKEY getWinKey(void);
+	HCRYPTKEY getWinKey(void) const;
 
 	/**
 	 * \brief Get a windows key provider
@@ -171,7 +171,7 @@ public :
 	 * @returns The key to use or 0 if this object does not hold one
 	 */
 
-	HCRYPTPROV getWinKeyProv(void);
+	HCRYPTPROV getWinKeyProv(void) const;
 
 	//@}
 
