@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: WinCAPICryptoProvider.hpp 351364 2005-06-04 11:30:26Z blautenb $
+ * $Id: WinCAPICryptoProvider.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -123,7 +123,7 @@ public :
 	 * @see WinCAPICryptoHash
 	 */
 
-	virtual XSECCryptoHash			* hashSHA1();
+	virtual XSECCryptoHash			* hashSHA1() const;
 
 	/**
 	 * \brief Return a SHA implementation.
@@ -136,7 +136,7 @@ public :
 	 * @see WinCAPICryptoHash
 	 */
 	 
-	virtual XSECCryptoHash			* hashSHA(int length = 160);
+	virtual XSECCryptoHash			* hashSHA(int length = 160) const;
 	
 	/**
 	 * \brief Return a HMAC SHA1 implementation.
@@ -149,7 +149,7 @@ public :
 	 * @see WinCAPICryptoHash
 	 */
 
-	virtual XSECCryptoHash			* hashHMACSHA1();
+	virtual XSECCryptoHash			* hashHMACSHA1() const;
 
 	/**
 	 * \brief Return a HMAC SHA(1-512) implementation.
@@ -163,7 +163,7 @@ public :
 	 * @see WinCAPICryptoHash
 	 */
 
-	virtual XSECCryptoHash			* hashHMACSHA(int length = 160);
+	virtual XSECCryptoHash			* hashHMACSHA(int length = 160) const;
 	
 	/**
 	 * \brief Return a MD5 implementation.
@@ -175,7 +175,7 @@ public :
 	 * @see WinCAPICryptoHash
 	 */
 
-	virtual XSECCryptoHash			* hashMD5();
+	virtual XSECCryptoHash			* hashMD5() const;
 
 	/**
 	 * \brief Return a HMAC MD5 implementation.
@@ -193,7 +193,7 @@ public :
 	 * @see WinCAPICryptoHash
 	 */
 
-	virtual XSECCryptoHash			* hashHMACMD5();
+	virtual XSECCryptoHash			* hashHMACMD5() const;
 
 	/**
 	 * \brief Return a HMAC key
@@ -205,7 +205,7 @@ public :
 	 * a value set within it.
 	 */
 
-	virtual XSECCryptoKeyHMAC		* keyHMAC(void);
+	virtual XSECCryptoKeyHMAC		* keyHMAC(void) const;
 
 	//@}
 
@@ -226,7 +226,7 @@ public :
 	 * @see XSCryptCryptoBase64
 	 */
 
-	virtual XSECCryptoBase64		* base64();
+	virtual XSECCryptoBase64		* base64() const;
 
 	//@}
 
@@ -242,7 +242,7 @@ public :
 	 * @see WinCAPICryptoKeyDSA
 	 */
 
-	virtual XSECCryptoKeyDSA		* keyDSA();
+	virtual XSECCryptoKeyDSA		* keyDSA() const;
 
 	/**
 	 * \brief Return an RSA key implementation object.
@@ -253,7 +253,7 @@ public :
 	 * @see WinCAPICryptoKeyRSA
 	 */
 
-	virtual XSECCryptoKeyRSA		* keyRSA();
+	virtual XSECCryptoKeyRSA		* keyRSA() const;
 
 	/**
 	 * \brief Return an X509 implementation object.
@@ -265,7 +265,7 @@ public :
 	 * @see WinCAPICryptoX509
 	 */
 
-	virtual XSECCryptoX509			* X509();
+	virtual XSECCryptoX509			* X509() const;
 
 	//@}
 
@@ -325,7 +325,7 @@ public :
 	 * symmetric algorithm is supported
 	 */
 
-	virtual bool algorithmSupported(XSECCryptoSymmetricKey::SymmetricKeyType alg);
+	virtual bool algorithmSupported(XSECCryptoSymmetricKey::SymmetricKeyType alg) const;
 
 	/**
 	 * \brief Determine whether a given algorithm is supported
@@ -334,7 +334,7 @@ public :
 	 * digest algorithm is supported
 	 */
 
-	virtual bool algorithmSupported(XSECCryptoHash::HashType alg);
+	virtual bool algorithmSupported(XSECCryptoHash::HashType alg) const;
 	
 	/**
 	 * \brief Return a Symmetric Key implementation object.
@@ -346,7 +346,7 @@ public :
 	 * @see XSECCryptoSymmetricKey
 	 */
 
-	virtual XSECCryptoSymmetricKey	* keySymmetric(XSECCryptoSymmetricKey::SymmetricKeyType alg);
+	virtual XSECCryptoSymmetricKey	* keySymmetric(XSECCryptoSymmetricKey::SymmetricKeyType alg) const;
 
 	/**
 	 * \brief Obtain some random octets
@@ -360,7 +360,7 @@ public :
 	 * @returns Number of bytes obtained.
 	 */
 
-	virtual unsigned int getRandom(unsigned char * buffer, unsigned int numOctets);
+	virtual unsigned int getRandom(unsigned char * buffer, unsigned int numOctets) const;
 
 
 	//@}
@@ -372,7 +372,7 @@ public :
 	 * \brief Returns a string that identifies the Crypto Provider
 	 */
 
-	virtual const XMLCh * getProviderName();
+	virtual const XMLCh * getProviderName() const;
 
 	//@}
 
