@@ -20,7 +20,7 @@
  * XSECCryptoSymmetricKey := Bulk encryption algorithms should all be
  *							implemented via this interface
  *
- * $Id: WinCAPICryptoSymmetricKey.cpp 394388 2006-04-15 22:42:13Z blautenb $
+ * $Id: WinCAPICryptoSymmetricKey.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -66,19 +66,7 @@ WinCAPICryptoSymmetricKey::~WinCAPICryptoSymmetricKey() {
 //           Basic Key interface methods
 // --------------------------------------------------------------------------------
 
-XSECCryptoSymmetricKey::SymmetricKeyType WinCAPICryptoSymmetricKey::getSymmetricKeyType() {
-
-	return m_keyType;
-
-}
-
-const XMLCh * WinCAPICryptoSymmetricKey::getProviderName() {
-
-	return DSIGConstants::s_unicodeStrPROVWinCAPI;
-
-}
-
-XSECCryptoKey * WinCAPICryptoSymmetricKey::clone() {
+XSECCryptoKey * WinCAPICryptoSymmetricKey::clone() const {
 
 	WinCAPICryptoSymmetricKey * ret;
 
