@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECCryptoKeyHMAC.hpp 351364 2005-06-04 11:30:26Z blautenb $
+ * $Id: XSECCryptoKeyHMAC.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -63,13 +63,13 @@ public :
 	 * public key, private key or a key pair
 	 */
 
-	virtual XSECCryptoKey::KeyType getKeyType() {return KEY_HMAC;}
+	virtual XSECCryptoKey::KeyType getKeyType() const {return KEY_HMAC;}
 
 	/**
 	 * \brief Replicate key
 	 */
 	
-	virtual XSECCryptoKey * clone() = 0;
+	virtual XSECCryptoKey * clone() const = 0;
 
 	//@}
 
@@ -105,7 +105,7 @@ public :
 	 * @returns number of bytes copied in
 	 */
 
-	virtual unsigned int getKey(safeBuffer &outBuf) = 0;
+	virtual unsigned int getKey(safeBuffer &outBuf) const = 0;
 
 	//@}
 };
