@@ -20,20 +20,18 @@
  * XSECAlgorithmMapper := Provides a table of AlgorithmHandlers
  *						  Mapped by Type URI
  *
- * $Id: XSECAlgorithmMapper.cpp 351386 2005-07-05 11:53:41Z blautenb $
+ * $Id: XSECAlgorithmMapper.cpp 575860 2007-09-15 02:53:05Z scantor $
  *
  */
 
 // XSEC Includes
 
 #include <xsec/framework/XSECDefs.hpp>
+#include <xsec/framework/XSECAlgorithmHandler.hpp>
 #include <xsec/framework/XSECAlgorithmMapper.hpp>
 #include <xsec/framework/XSECError.hpp>
 #include <xsec/utils/XSECDOMUtils.hpp>
 
-#include "XSECAlgorithmMapper.hpp"
-#include "XSECAlgorithmHandler.hpp"
-
 // Xerces
 
 #include <xercesc/util/XMLString.hpp>
