@@ -21,12 +21,14 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECError.hpp 394903 2006-04-18 10:24:39Z blautenb $
+ * $Id: XSECError.hpp 578373 2007-09-22 05:34:23Z scantor $
  *
  */
 
 #include <xsec/framework/XSECDefs.hpp>
 #include <xsec/framework/XSECException.hpp>
+#include <xsec/enc/XSECCryptoException.hpp>
+#include <new>
 
 /**
  * @defgroup pubsig Main Signature API
@@ -54,11 +56,11 @@ extern const char * XSECExceptionStrings [];
 			throw XSECException (XSECException::MemoryAllocationFail); \
 		}\
 	} \
-	catch (XSECException &e) \
+	catch (XSECCryptoException &e) \
 	{\
 		throw XSECException (XSECException::InternalError, e.getMsg()); \
 	} \
-	catch (...) { \
+	catch (std::bad_alloc&) { \
 		throw XSECException (XSECException::MemoryAllocationFail); \
 	}
 
@@ -70,11 +72,12 @@ extern const char * XSECExceptionStrings [];
 			throw XSECException (XSECException::MemoryAllocationFail); \
 		} \
 	} \
-	catch (XSECException &e) \
+	catch (XSECCryptoException &e) \
 	{\
 		throw XSECException (XSECException::InternalError, e.getMsg()); \
 	} \
-	catch (...) { \
+	catch (std::bad_alloc&) { \
 		throw XSECException (XSECException::MemoryAllocationFail); \
 	}
+
 #endif
