@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: cipher.cpp,v 1.22 2005/05/15 06:49:41 blautenb Exp $
+ * $Id: cipher.cpp 450286 2006-09-27 01:47:51Z blautenb $
  *
  */
 
@@ -31,6 +31,7 @@
 #include <xsec/framework/XSECProvider.hpp>
 #include <xsec/framework/XSECException.hpp>
 #include <xsec/enc/XSECCryptoException.hpp>
+#include <xsec/enc/XSECCryptoUtils.hpp>
 #include <xsec/enc/OpenSSL/OpenSSLCryptoSymmetricKey.hpp>
 #include <xsec/utils/XSECBinTXFMInputStream.hpp>
 #include <xsec/xenc/XENCEncryptedData.hpp>
@@ -101,7 +102,7 @@ XALAN_USING_XALAN(XalanTransformer)
 
 #endif
 
-#if !defined (HAVE_OPENSSL) && !defined(HAVE_WINCAPI)
+#if !defined (HAVE_OPENSSL) && !defined(HAVE_WINCAPI) && !defined(HAVE_NSS)
 #	error No available cryptoAPI
 #endif
 
@@ -125,6 +126,14 @@ XALAN_USING_XALAN(XalanTransformer)
 
 #endif
 
+#if defined (HAVE_NSS)
+
+#	include <xsec/enc/NSS/NSSCryptoProvider.hpp>
+#	include <xsec/enc/NSS/NSSCryptoSymmetricKey.hpp>
+#	include <xsec/enc/NSS/NSSCryptoKeyHMAC.hpp>
+
+#endif
+
 #include <time.h>
 
 #ifdef XSEC_NO_XALAN
@@ -172,13 +181,20 @@ void printUsage(void) {
 	cerr << "                  <filename> - for X509 PEM files (must be an RSA KEK certificate\n";
 	cerr << "                  <filename> <password> - for RSA private key files (MUST be a KEK)\n";
 	cerr << "                  <key-string> - For a string to use as the key for AES or DES keys\n";
+	cerr << "     --xkms/-x\n";
+	cerr << "         The key that follows on the command line is to be interpreted as\n";
+	cerr << "         an XKMS RSAKeyPair encryption key\n";
 	cerr << "     --interop/-i\n";
 	cerr << "         Use the interop resolver for Baltimore interop examples\n";
 	cerr << "     --out-file/-o\n";
 	cerr << "         Output the result to the indicated file (rather than stdout)\n";
-#if defined (HAVE_OPENSSL) && defined (HAVE_WINCAPI)
+#if defined (HAVE_WINCAPI)
 	cerr << "     --wincapi/-w\n";
-	cerr << "         Use Windows Crypto API rather than OpenSSL\n";
+	cerr << "         Force use of Windows Crypto API\n";
+#endif
+#if defined (HAVE_NSS)
+	cerr << "     --nss/-n\n";
+	cerr << "         Force use of NSS Crypto API\n";
 #endif
 
 	cerr << "\n     Exits with codes :\n";
@@ -200,6 +216,7 @@ int evaluate(int argc, char ** argv) {
 	bool					encryptFileAsData = false;
 	bool					parseXMLInput = true;
 	bool					doXMLOutput = false;
+	bool					isXKMSKey = false;
 	XSECCryptoKey			* kek = NULL;
 	XSECCryptoKey			* key = NULL;
 	int						keyLen = 0;
@@ -229,19 +246,19 @@ int evaluate(int argc, char ** argv) {
 
 	while (paramCount < argc - 1) {
 
-		if (stricmp(argv[paramCount], "--decrypt-element") == 0 || stricmp(argv[paramCount], "-de") == 0) {
+		if (_stricmp(argv[paramCount], "--decrypt-element") == 0 || _stricmp(argv[paramCount], "-de") == 0) {
 			paramCount++;
 			doDecrypt = true;
 			doDecryptElement = true;
 			doXMLOutput = true;
 			parseXMLInput = true;
 		}
-		else if (stricmp(argv[paramCount], "--interop") == 0 || stricmp(argv[paramCount], "-i") == 0) {
+		else if (_stricmp(argv[paramCount], "--interop") == 0 || _stricmp(argv[paramCount], "-i") == 0) {
 			// Use the interop key resolver
 			useInteropResolver = true;
 			paramCount++;
 		}
-		else if (stricmp(argv[paramCount], "--encrypt-file") == 0) {
+		else if (_stricmp(argv[paramCount], "--encrypt-file") == 0) {
 			// Use this file as the input
 			doDecrypt = false;
 			encryptFileAsData = true;
@@ -249,7 +266,7 @@ int evaluate(int argc, char ** argv) {
 			parseXMLInput = false;
 			paramCount++;
 		}
-		else if (stricmp(argv[paramCount], "--encrypt-xml") == 0 || stricmp(argv[paramCount], "-ex") == 0) {
+		else if (_stricmp(argv[paramCount], "--encrypt-xml") == 0 || _stricmp(argv[paramCount], "-ex") == 0) {
 			// Us this file as an XML input file
 			doDecrypt = false;
 			encryptFileAsData = false;
@@ -257,7 +274,7 @@ int evaluate(int argc, char ** argv) {
 			parseXMLInput = true;
 			paramCount++;
 		}
-		else if (stricmp(argv[paramCount], "--out-file") == 0 || stricmp(argv[paramCount], "-o") == 0) {
+		else if (_stricmp(argv[paramCount], "--out-file") == 0 || _stricmp(argv[paramCount], "-o") == 0) {
 			if (paramCount +2 >= argc) {
 				printUsage();
 				return 1;
@@ -266,16 +283,28 @@ int evaluate(int argc, char ** argv) {
 			outfile = argv[paramCount];
 			paramCount++;
 		}
+		else if (_stricmp(argv[paramCount], "--xkms") == 0 || _stricmp(argv[paramCount], "-x") == 0) {
+			paramCount++;
+			isXKMSKey = true;
+		}
 
-#if defined (HAVE_WINCAPI) && defined (HAVE_OPENSSL)
-		else if (stricmp(argv[paramCount], "--wincapi") == 0 || stricmp(argv[paramCount], "-w") == 0) {
+#if defined (HAVE_WINCAPI)
+		else if (_stricmp(argv[paramCount], "--wincapi") == 0 || _stricmp(argv[paramCount], "-w") == 0) {
 			// Use the interop key resolver
 			WinCAPICryptoProvider * cp = new WinCAPICryptoProvider();
 			XSECPlatformUtils::SetCryptoProvider(cp);
 			paramCount++;
 		}
 #endif
-		else if (stricmp(argv[paramCount], "--key") == 0 || stricmp(argv[paramCount], "-k") == 0) {
+#if defined (HAVE_NSS)
+		else if (_stricmp(argv[paramCount], "--nss") == 0 || _stricmp(argv[paramCount], "-n") == 0) {
+			// NSS Crypto Provider
+			NSSCryptoProvider * cp = new NSSCryptoProvider();
+			XSECPlatformUtils::SetCryptoProvider(cp);
+			paramCount++;
+		}
+#endif
+		else if (_stricmp(argv[paramCount], "--key") == 0 || _stricmp(argv[paramCount], "-k") == 0) {
 
 			// Have a key!
 			paramCount++;
@@ -283,7 +312,7 @@ int evaluate(int argc, char ** argv) {
 			XSECCryptoSymmetricKey::SymmetricKeyType loadKeyAs =
 				XSECCryptoSymmetricKey::KEY_NONE;
 
-			if (stricmp(argv[paramCount], "kek") == 0) {
+			if (_stricmp(argv[paramCount], "kek") == 0) {
 				isKEK = true;
 				paramCount++;
 				if (paramCount >= argc) {
@@ -292,10 +321,10 @@ int evaluate(int argc, char ** argv) {
 				}
 			}
 
-			if (stricmp(argv[paramCount], "3DES") == 0 ||
-				stricmp(argv[paramCount], "AES128") == 0 ||
-				stricmp(argv[paramCount], "AES192") == 0 ||
-				stricmp(argv[paramCount], "AES256") == 0 ) {
+			if (_stricmp(argv[paramCount], "3DES") == 0 ||
+				_stricmp(argv[paramCount], "AES128") == 0 ||
+				_stricmp(argv[paramCount], "AES192") == 0 ||
+				_stricmp(argv[paramCount], "AES256") == 0 ) {
 				
 				if (paramCount +2 >= argc) {
 					printUsage();
@@ -346,12 +375,20 @@ int evaluate(int argc, char ** argv) {
 					cerr << "Key string too long\n";
 					return 2;
 				}
-				memset(keyStr, 0, 64);
-				strcpy((char *) keyStr, argv[paramCount]);
-				paramCount++;
 				XSECCryptoSymmetricKey * sk = 
 					XSECPlatformUtils::g_cryptoProvider->keySymmetric(loadKeyAs);
-				sk->setKey(keyStr, keyLen);
+
+				if (isXKMSKey) {
+					unsigned char kbuf[XSEC_MAX_HASH_SIZE];
+					CalculateXKMSKEK((unsigned char *) argv[paramCount], (int) strlen(argv[paramCount]), kbuf, XSEC_MAX_HASH_SIZE);
+					sk->setKey(kbuf, keyLen);
+				}
+				else {
+					memset(keyStr, 0, 64);
+					strcpy((char *) keyStr, argv[paramCount]);
+					sk->setKey(keyStr, keyLen);
+				}
+				paramCount++;
 				if (isKEK)
 					kek = sk;
 				else
@@ -359,10 +396,9 @@ int evaluate(int argc, char ** argv) {
 			}
 
 
-
 #if defined (HAVE_OPENSSL)
 
-			else if (stricmp(argv[paramCount], "RSA") == 0) {
+			else if (_stricmp(argv[paramCount], "RSA") == 0) {
 				// RSA private key file
 
 				if (paramCount + 3 >= argc) {
@@ -409,7 +445,7 @@ int evaluate(int argc, char ** argv) {
 				paramCount += 3;
 			}
 
-			else if (stricmp(argv[paramCount], "X509") == 0) {
+			else if (_stricmp(argv[paramCount], "X509") == 0) {
 
 				// X509 cert used to load an encrypting key
 
@@ -590,7 +626,7 @@ int evaluate(int argc, char ** argv) {
 				// Map out base path of the file
 				char path[_MAX_PATH];
 				char baseURI[(_MAX_PATH * 2) + 10];
-				getcwd(path, _MAX_PATH);
+				_getcwd(path, _MAX_PATH);
 
 				strcpy(baseURI, "file:///");		
 
@@ -707,7 +743,27 @@ int evaluate(int argc, char ** argv) {
 				XERCES_CPP_NAMESPACE_QUALIFIER chNull
 			};
 
-			DOMImplementation *impl = DOMImplementationRegistry::getDOMImplementation(core);
+            DOMImplementation *impl = DOMImplementationRegistry::getDOMImplementation(core);
+
+#if defined (XSEC_XERCES_DOMLSSERIALIZER)
+            // DOM L3 version as per Xerces 3.0 API
+            DOMLSSerializer   *theSerializer = ((DOMImplementationLS*)impl)->createLSSerializer();
+            Janitor<DOMLSSerializer> j_theSerializer(theSerializer);
+            
+            // Get the config so we can set up pretty printing
+            DOMConfiguration *dc = theSerializer->getDomConfig();
+            dc->setParameter(XMLUni::fgDOMWRTFormatPrettyPrint, false);
+
+            // Now create an output object to format to UTF-8
+            DOMLSOutput *theOutput = ((DOMImplementationLS*)impl)->createLSOutput();
+            Janitor<DOMLSOutput> j_theOutput(theOutput);
+
+            theOutput->setEncoding(MAKE_UNICODE_STRING("UTF-8"));
+            theOutput->setByteStream(formatTarget);
+
+            theSerializer->write(doc, theOutput);
+
+#else			
 			DOMWriter         *theSerializer = ((DOMImplementationLS*)impl)->createDOMWriter();
 			Janitor<DOMWriter> j_theSerializer(theSerializer);
 
@@ -716,7 +772,7 @@ int evaluate(int argc, char ** argv) {
 				theSerializer->setFeature(XMLUni::fgDOMWRTFormatPrettyPrint, false);
 
 			theSerializer->writeNode(formatTarget, *doc);
-			
+#endif	
 			cout << endl;
 
 		}
