@@ -22,7 +22,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: xtest.cpp,v 1.53 2005/05/22 02:40:07 blautenb Exp $
+ * $Id: xtest.cpp 450742 2006-09-28 07:49:40Z blautenb $
  *
  */
 
@@ -101,6 +101,11 @@ XALAN_USING_XALAN(XalanTransformer)
 #	include <xsec/enc/WinCAPI/WinCAPICryptoKeyRSA.hpp>
 #	include <xsec/enc/WinCAPI/WinCAPICryptoProvider.hpp>
 #endif
+#if defined (HAVE_NSS)
+#	include <xsec/enc/NSS/NSSCryptoKeyHMAC.hpp>
+#	include <xsec/enc/NSS/NSSCryptoKeyRSA.hpp>
+#	include <xsec/enc/NSS/NSSCryptoProvider.hpp>
+#endif
 
 using std::ostream;
 using std::cout;
@@ -122,6 +127,7 @@ XERCES_CPP_NAMESPACE_USE
 
 bool	g_printDocs = false;
 bool	g_useWinCAPI = false;
+bool	g_useNSS = false;
 bool    g_haveAES = true;
 
 // --------------------------------------------------------------------------------
@@ -336,24 +342,24 @@ DOMNode * findNode(DOMNode * n, XMLCh * name) {
 XSECCryptoKeyHMAC * createHMACKey(const unsigned char * str) {
 
 	// Create the HMAC key
-	XSECCryptoKeyHMAC * hmacKey;
+	XSECCryptoKeyHMAC * hmacKey = NULL;
 
-#if defined (HAVE_OPENSSL) && defined(HAVE_WINCAPI)
+#if defined(HAVE_WINCAPI)
 
 	if (g_useWinCAPI == true) {
 		hmacKey = new WinCAPICryptoKeyHMAC(0);
 	}
-	else {
-		hmacKey = new OpenSSLCryptoKeyHMAC();
+#endif
+
+# if defined (HAVE_NSS)
+	if (g_useNSS == true) {
+		hmacKey = new NSSCryptoKeyHMAC();
 	}
-#else
-#	if defined (HAVE_OPENSSL)
+#endif
+
+#if defined (HAVE_OPENSSL)
+	if (hmacKey == NULL)
 		hmacKey = new OpenSSLCryptoKeyHMAC();
-#	else
-#		if defined (HAVE_WINCAPI)
-		hmacKey = new WinCAPICryptoKeyHMAC(0);
-#		endif
-#	endif
 #endif
 
 	hmacKey->setKey((unsigned char *) str, (unsigned int) strlen((char *)str));
@@ -399,7 +405,7 @@ DOMDocument * createTestDoc(DOMImplementation * impl) {
 
 	DOMElement  *catElem = doc->createElement(MAKE_UNICODE_STRING("category"));
 	rootElem->appendChild(catElem);
-	catElem->setAttribute(MAKE_UNICODE_STRING("idea"), MAKE_UNICODE_STRING("great"));
+	catElem->setAttributeNS(NULL,MAKE_UNICODE_STRING("idea"), MAKE_UNICODE_STRING("great"));
 
 	DOMText    *catDataVal = doc->createTextNode(MAKE_UNICODE_STRING("XML Security Tools"));
 	catElem->appendChild(catDataVal);
@@ -416,18 +422,41 @@ void outputDoc(DOMImplementation * impl, DOMDocument * doc) {
 	if (g_printDocs == false)
 		return;
 
+	XMLFormatTarget *formatTarget = new StdOutFormatTarget();
+
+#if defined (XSEC_XERCES_DOMLSSERIALIZER)
+
+    // DOM L3 version as per Xerces 3.0 API
+    DOMLSSerializer   *theSerializer = ((DOMImplementationLS*)impl)->createLSSerializer();
+
+    // Get the config so we can set up pretty printing
+    DOMConfiguration *dc = theSerializer->getDomConfig();
+    dc->setParameter(XMLUni::fgDOMWRTFormatPrettyPrint, false);
+
+    // Now create an output object to format to UTF-8
+    DOMLSOutput *theOutput = ((DOMImplementationLS*)impl)->createLSOutput();
+    Janitor<DOMLSOutput> j_theOutput(theOutput);
+
+    theOutput->setEncoding(MAKE_UNICODE_STRING("UTF-8"));
+    theOutput->setByteStream(formatTarget);
+
+#else
+
 	DOMWriter         *theSerializer = ((DOMImplementationLS*)impl)->createDOMWriter();
 
 	theSerializer->setEncoding(MAKE_UNICODE_STRING("UTF-8"));
 	if (theSerializer->canSetFeature(XMLUni::fgDOMWRTFormatPrettyPrint, false))
 		theSerializer->setFeature(XMLUni::fgDOMWRTFormatPrettyPrint, false);
 
-
-	XMLFormatTarget *formatTarget = new StdOutFormatTarget();
+#endif
 
 	cerr << endl;
 
+#if defined (XSEC_XERCES_DOMLSSERIALIZER)
+    theSerializer->write(doc, theOutput);
+#else
 	theSerializer->writeNode(formatTarget, *doc);
+#endif
 	
 	cout << endl;
 
@@ -448,6 +477,26 @@ bool reValidateSig(DOMImplementation *impl, DOMDocument * inDoc, XSECCryptoKey *
 
 	try {
 
+		MemBufFormatTarget *formatTarget = new MemBufFormatTarget();
+#if defined (XSEC_XERCES_DOMLSSERIALIZER)
+
+        // DOM L3 version as per Xerces 3.0 API
+        DOMLSSerializer   *theSerializer = ((DOMImplementationLS*)impl)->createLSSerializer();
+
+        // Get the config so we can set up pretty printing
+        DOMConfiguration *dc = theSerializer->getDomConfig();
+        dc->setParameter(XMLUni::fgDOMWRTFormatPrettyPrint, false);
+        
+        // Now create an output object to format to UTF-8
+        DOMLSOutput *theOutput = ((DOMImplementationLS*)impl)->createLSOutput();
+        Janitor<DOMLSOutput> j_theOutput(theOutput);
+        
+        theOutput->setEncoding(MAKE_UNICODE_STRING("UTF-8"));
+        theOutput->setByteStream(formatTarget);
+
+        theSerializer->write(inDoc,theOutput);
+#else
+
 		DOMWriter *theSerializer = ((DOMImplementationLS*)impl)->createDOMWriter();
 
 		theSerializer->setEncoding(MAKE_UNICODE_STRING("UTF-8"));
@@ -455,10 +504,11 @@ bool reValidateSig(DOMImplementation *impl, DOMDocument * inDoc, XSECCryptoKey *
 		if (theSerializer->canSetFeature(XMLUni::fgDOMWRTFormatPrettyPrint, false))
 			theSerializer->setFeature(XMLUni::fgDOMWRTFormatPrettyPrint, false);
 
-		MemBufFormatTarget *formatTarget = new MemBufFormatTarget();
 
 		theSerializer->writeNode(formatTarget, *inDoc);
 
+#endif
+
 		// Copy to a new buffer
 		int len = formatTarget->getLen();
 		char * mbuf = new char [len + 1];
@@ -548,7 +598,9 @@ void unitTestEnvelopingSignature(DOMImplementation * impl) {
 		sig->setDSIGNSPrefix(MAKE_UNICODE_STRING("ds"));
 		sig->setPrettyPrint(true);
 
-		sigNode = sig->createBlankSignature(doc, CANON_C14N_COM, SIGNATURE_HMAC, HASH_SHA1);
+		sigNode = sig->createBlankSignature(doc, 
+			DSIGConstants::s_unicodeStrURIC14N_COM,
+			DSIGConstants::s_unicodeStrURIHMAC_SHA1);
 
 		doc->appendChild(sigNode);
 
@@ -561,7 +613,8 @@ void unitTestEnvelopingSignature(DOMImplementation * impl) {
 		obj->appendChild(txt);
 
 		// Add a Reference
-		sig->createReference(MAKE_UNICODE_STRING("#ObjectId"));
+		sig->createReference(MAKE_UNICODE_STRING("#ObjectId"), 
+			DSIGConstants::s_unicodeStrURISHA1);
 
 		// Get a key
 		cerr << "signing ... ";
@@ -656,7 +709,9 @@ void unitTestBase64NodeSignature(DOMImplementation * impl) {
 #if defined (XSEC_XERCES_HAS_SETIDATTRIBUTE)
 		sig->setIdByAttributeName(false);		// Do not search by name
 #endif
-		sigNode = sig->createBlankSignature(doc, CANON_C14N_COM, SIGNATURE_HMAC, HASH_SHA1);
+		sigNode = sig->createBlankSignature(doc, 
+			DSIGConstants::s_unicodeStrURIC14N_COM,
+			DSIGConstants::s_unicodeStrURIHMAC_SHA1);
 
 		doc->appendChild(sigNode);
 
@@ -669,7 +724,8 @@ void unitTestBase64NodeSignature(DOMImplementation * impl) {
 		obj->appendChild(txt);
 
 		// Add a Reference
-		DSIGReference * ref = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"));
+		DSIGReference * ref = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"),
+			DSIGConstants::s_unicodeStrURISHA1);
 		// Add a Base64 transform
 		ref->appendBase64Transform();
 
@@ -766,7 +822,9 @@ void unitTestLongSHA(DOMImplementation * impl) {
 		sig->setDSIGNSPrefix(MAKE_UNICODE_STRING("ds"));
 		sig->setPrettyPrint(true);
 
-		sigNode = sig->createBlankSignature(doc, CANON_C14N_COM, SIGNATURE_HMAC, HASH_SHA512);
+		sigNode = sig->createBlankSignature(doc, 
+			DSIGConstants::s_unicodeStrURIC14N_COM,
+			DSIGConstants::s_unicodeStrURIHMAC_SHA512);
 
 		doc->appendChild(sigNode);
 
@@ -779,14 +837,20 @@ void unitTestLongSHA(DOMImplementation * impl) {
 		obj->appendChild(txt);
 
 		// Add a Reference
-		cerr << "224 ... ";
-		ref[0] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"), HASH_SHA224);
+		if (XSECPlatformUtils::g_cryptoProvider->algorithmSupported(XSECCryptoHash::HASH_SHA224)) {
+			cerr << "224 ... ";
+			ref[0] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"), 
+				DSIGConstants::s_unicodeStrURISHA224);
+		}
 		cerr << "256 ... ";
-		ref[1] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"), HASH_SHA256);
+		ref[1] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"), 
+			DSIGConstants::s_unicodeStrURISHA256);
 		cerr << "384 ... ";
-		ref[2] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"), HASH_SHA384);
+		ref[2] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"),
+			DSIGConstants::s_unicodeStrURISHA384);
 		cerr << "512 ... ";
-		ref[3] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"), HASH_SHA512);
+		ref[3] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"),
+			DSIGConstants::s_unicodeStrURISHA512);
 
 		// Get a key
 		cerr << "signing ... ";
@@ -902,7 +966,216 @@ void unitTestLongSHA(DOMImplementation * impl) {
 	}
 
 }
+
+void unitTestRSASig(DOMImplementation * impl, XSECCryptoKeyRSA * k, const XMLCh * AlgURI) {
+
+	// Given a specific RSA key and particular algorithm URI, sign and validate a document
+
+	try {
+		
+		// Create a document
+    
+		DOMDocument * doc = impl->createDocument();
+
+		// Create the signature
+
+		XSECProvider prov;
+		DSIGSignature *sig;
+		DOMElement *sigNode;
+		DSIGReference *ref[4];
+		
+		sig = prov.newSignature();
+		sig->setDSIGNSPrefix(MAKE_UNICODE_STRING("ds"));
+		sig->setPrettyPrint(true);
+
+		sigNode = sig->createBlankSignature(doc, 
+			DSIGConstants::s_unicodeStrURIC14N_COM,
+			AlgURI);
+
+		doc->appendChild(sigNode);
+
+		// Add an object
+		DSIGObject * obj = sig->appendObject();
+		obj->setId(MAKE_UNICODE_STRING("ObjectId"));
+
+		// Create a text node
+		DOMText * txt= doc->createTextNode(MAKE_UNICODE_STRING("A test string"));
+		obj->appendChild(txt);
+
+		// Add a Reference
+		ref[0] = sig->createReference(MAKE_UNICODE_STRING("#ObjectId"), 
+			DSIGConstants::s_unicodeStrURISHA1);
+
+		// Get a key
+		cerr << "signing ... ";
+
+		sig->setSigningKey(k->clone());
+		sig->sign();
+
+		cerr << "OK ... ";
+
+		cerr << "validating ... ";
+		if (!sig->verify()) {
+			cerr << "bad verify!" << endl;
+			exit(1);
+		}
+
+		cerr << "OK ... serialise and re-verify ... ";
+		if (!reValidateSig(impl, doc, k)) {
+
+			cerr << "bad verify!" << endl;
+			exit(1);
+
+		}
+
+		cerr << "OK";
+
+#if 0
+#if defined HAVE_OPENSSL
+
+		if (g_useWinCAPI || g_useNSS) {
+
+			cerr << " ... validate against OpenSSL" << endl;
+
+			BIO * bioMem = BIO_new(BIO_s_mem());
+			BIO_puts(bioMem, s_tstRSAPrivateKey);
+			EVP_PKEY * pk = PEM_read_bio_PrivateKey(bioMem, NULL, NULL, NULL);
+
+			OpenSSLCryptoKeyRSA * rsaKey = new OpenSSLCryptoKeyRSA(pk);
+
+			sig->setSigningKey(rsaKey);
+			if (!sig->verify()) {
+				cerr << "bad verify!" << endl;
+				exit (1);
+			}
+
+			cerr << "OK";
+
+			BIO_free(bioMem);
+			EVP_PKEY_free(pk);
+		}
+#endif
+#endif
+
+		cerr << "\n";	
+
+		outputDoc(impl, doc);
+		doc->release();
+		
+
+	}
+
+	catch (XSECException &e)
+	{
+		cerr << "An error occured during signature processing\n   Message: ";
+		char * ce = XMLString::transcode(e.getMsg());
+		cerr << ce << endl;
+		delete ce;
+		exit(1);
+		
+	}	
+	catch (XSECCryptoException &e)
+	{
+		cerr << "A cryptographic error occured during signature processing\n   Message: "
+		<< e.getMsg() << endl;
+		exit(1);
+	}
+
+}
+
+
+void unitTestRSA(DOMImplementation * impl) {
+
+	/* First we load some keys to use! */
+
+	XSECCryptoKeyRSA * rsaKey;
+
+#if defined (HAVE_OPENSSL)
+	if (!g_useWinCAPI && !g_useNSS) {
+		// Load the key
+		BIO * bioMem = BIO_new(BIO_s_mem());
+		BIO_puts(bioMem, s_tstRSAPrivateKey);
+		EVP_PKEY * pk = PEM_read_bio_PrivateKey(bioMem, NULL, NULL, NULL);
+
+		rsaKey = new OpenSSLCryptoKeyRSA(pk);
+
+		BIO_free(bioMem);
+		EVP_PKEY_free(pk);
+	}
+#endif
+
+#if defined (HAVE_WINCAPI)
+	if (g_useWinCAPI) {
+
+		// Use the internal key
+		WinCAPICryptoProvider *cp = (WinCAPICryptoProvider *) (XSECPlatformUtils::g_cryptoProvider);
+		HCRYPTPROV p = cp->getApacheKeyStore();
+			
+		rsaKey = new WinCAPICryptoKeyRSA(p, AT_KEYEXCHANGE, true);
+	}
+
+#endif
+
+#if defined (HAVE_NSS)
+	if (g_useNSS) {
+		// Use the internal key
+		NSSCryptoProvider *cp = (NSSCryptoProvider *) (XSECPlatformUtils::g_cryptoProvider);
+		
+		// Heavily based on Mozilla example code
+		SECKEYPrivateKey *prvKey = 0;
+		SECKEYPublicKey *pubKey = 0;
+		PK11SlotInfo *slot = 0;
+		PK11RSAGenParams rsaParams;
+
+		// Use a bog standard key size
+		rsaParams.keySizeInBits = 1024;
+		rsaParams.pe = 65537;
+		
+		// We need somewhere to temporarily store a generated key
+		slot = PK11_GetInternalKeySlot();
+		if (!slot) { 
+			cerr << "Error generating key - can't get NSS slot\n";
+			exit (1);
+		}
+		
+		// Do the generate
+		prvKey = PK11_GenerateKeyPair(slot, CKM_RSA_PKCS_KEY_PAIR_GEN, &rsaParams,
+			&pubKey, PR_FALSE, PR_TRUE, 0);
+		
+		if (!prvKey) {
+			if (slot)
+				PK11_FreeSlot(slot);
+			cerr << "Error generating key within NSS\n";
+			exit (1);
+		}
+		
+		// Now use the key!
+		rsaKey = new NSSCryptoKeyRSA(pubKey, prvKey);
+
+	}
+#endif
+
+	cerr << "Unit testing RSA-SHA1 signature ... ";
+	unitTestRSASig(impl, (XSECCryptoKeyRSA *) rsaKey->clone(), DSIGConstants::s_unicodeStrURIRSA_SHA1);
+
+	if (XSECPlatformUtils::g_cryptoProvider->algorithmSupported(XSECCryptoHash::HASH_SHA512)) {
+		cerr << "Unit testing RSA-SHA224 signature ... ";
+		unitTestRSASig(impl, (XSECCryptoKeyRSA *) rsaKey->clone(), DSIGConstants::s_unicodeStrURIRSA_SHA224);
+		cerr << "Unit testing RSA-SHA256 signature ... ";
+		unitTestRSASig(impl, (XSECCryptoKeyRSA *) rsaKey->clone(), DSIGConstants::s_unicodeStrURIRSA_SHA256);
+		cerr << "Unit testing RSA-SHA384 signature ... ";
+		unitTestRSASig(impl, (XSECCryptoKeyRSA *) rsaKey->clone(), DSIGConstants::s_unicodeStrURIRSA_SHA384);
+		cerr << "Unit testing RSA-SHA512 signature ... ";
+		unitTestRSASig(impl, (XSECCryptoKeyRSA *) rsaKey->clone(), DSIGConstants::s_unicodeStrURIRSA_SHA512);
+	}
+	else
+		cerr << "Skipping non SHA 224/256/384/512 RSA signatures" << endl;
+
+	cerr << "Unit testing RSA-MD5 signature ... ";
+	unitTestRSASig(impl, rsaKey, DSIGConstants::s_unicodeStrURIRSA_MD5);
 	
+		
+}
 void unitTestSignature(DOMImplementation * impl) {
 
 	// Test an enveloping signature
@@ -918,6 +1191,9 @@ void unitTestSignature(DOMImplementation * impl) {
 		unitTestLongSHA(impl);
 	else
 		cerr << "Skipping long SHA hash tests as SHA512 not supported by crypto provider" << endl;
+
+	// Test RSA Signatures
+	unitTestRSA(impl);
 }
 
 // --------------------------------------------------------------------------------
@@ -950,7 +1226,9 @@ void testSignature(DOMImplementation *impl) {
 		sig->setDSIGNSPrefix(MAKE_UNICODE_STRING("ds"));
 		sig->setPrettyPrint(true);
 
-		sigNode = sig->createBlankSignature(doc, CANON_C14N_COM, SIGNATURE_HMAC, HASH_SHA1);
+		sigNode = sig->createBlankSignature(doc, 
+			DSIGConstants::s_unicodeStrURIC14N_COM,
+			DSIGConstants::s_unicodeStrURIHMAC_SHA1);
 		DOMElement * rootElem = doc->getDocumentElement();
 		DOMNode * prodElem = rootElem->getFirstChild();
 
@@ -963,34 +1241,43 @@ void testSignature(DOMImplementation *impl) {
 		 * Add some test references
 		 */
 
-		ref[0] = sig->createReference(MAKE_UNICODE_STRING(""));
+		ref[0] = sig->createReference(MAKE_UNICODE_STRING(""),
+			DSIGConstants::s_unicodeStrURISHA1);
 		ref[0]->appendEnvelopedSignatureTransform();
 
-		ref[1] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"));
+		ref[1] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"),
+			DSIGConstants::s_unicodeStrURISHA1);
 		ref[1]->appendEnvelopedSignatureTransform();
-		ref[1]->appendCanonicalizationTransform(CANON_C14N_NOC);
+		ref[1]->appendCanonicalizationTransform(DSIGConstants::s_unicodeStrURIC14N_NOC);
 
-		ref[2] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"));
+		ref[2] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"),
+			DSIGConstants::s_unicodeStrURISHA1);
 		ref[2]->appendEnvelopedSignatureTransform();
-		ref[2]->appendCanonicalizationTransform(CANON_C14N_COM);
+		ref[2]->appendCanonicalizationTransform(DSIGConstants::s_unicodeStrURIC14N_COM);
 
-		ref[3] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"));
+		ref[3] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"),
+			DSIGConstants::s_unicodeStrURISHA1);
 		ref[3]->appendEnvelopedSignatureTransform();
-		ref[3]->appendCanonicalizationTransform(CANON_C14NE_NOC);
+		ref[3]->appendCanonicalizationTransform(DSIGConstants::s_unicodeStrURIEXC_C14N_NOC);
 
-		ref[4] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"));
+		ref[4] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"),
+			DSIGConstants::s_unicodeStrURISHA1);
 		ref[4]->appendEnvelopedSignatureTransform();
-		ref[4]->appendCanonicalizationTransform(CANON_C14NE_COM);
+		ref[4]->appendCanonicalizationTransform(DSIGConstants::s_unicodeStrURIEXC_C14N_COM);
 
-		ref[5] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"));
+		ref[5] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"),
+			DSIGConstants::s_unicodeStrURISHA1);
 		ref[5]->appendEnvelopedSignatureTransform();
-		DSIGTransformC14n * ce = ref[5]->appendCanonicalizationTransform(CANON_C14NE_COM);
+		DSIGTransformC14n * ce = ref[5]->appendCanonicalizationTransform(
+			DSIGConstants::s_unicodeStrURIEXC_C14N_COM);
 		ce->addInclusiveNamespace("foo");
 
 		sig->setECNSPrefix(MAKE_UNICODE_STRING("ec"));
-		ref[6] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"));
+		ref[6] = sig->createReference(MAKE_UNICODE_STRING("#xpointer(/)"),
+			DSIGConstants::s_unicodeStrURISHA1);
 		ref[6]->appendEnvelopedSignatureTransform();
-		ce = ref[6]->appendCanonicalizationTransform(CANON_C14NE_COM);
+		ce = ref[6]->appendCanonicalizationTransform(
+			DSIGConstants::s_unicodeStrURIEXC_C14N_COM);
 		ce->addInclusiveNamespace("foo");
 
 #ifdef XSEC_NO_XALAN
@@ -1004,12 +1291,14 @@ void testSignature(DOMImplementation *impl) {
 		 */
 
 
-		ref[7] = sig->createReference(MAKE_UNICODE_STRING(""));
+		ref[7] = sig->createReference(MAKE_UNICODE_STRING(""),
+			DSIGConstants::s_unicodeStrURISHA1);
 		sig->setXPFNSPrefix(MAKE_UNICODE_STRING("xpf"));
 		DSIGTransformXPathFilter * xpf = ref[7]->appendXPathFilterTransform();
 		xpf->appendFilter(FILTER_INTERSECT, MAKE_UNICODE_STRING("//ADoc/category"));
 
-		ref[8] = sig->createReference(MAKE_UNICODE_STRING(""));
+		ref[8] = sig->createReference(MAKE_UNICODE_STRING(""),
+			DSIGConstants::s_unicodeStrURISHA1);
 		/*		ref[5]->appendXPathTransform("ancestor-or-self::dsig:Signature", 
 				"xmlns:dsig=http://www.w3.org/2000/09/xmldsig#"); */
 
@@ -1126,16 +1415,35 @@ count(ancestor-or-self::dsig:Signature)");
 
 		cerr << "Serialising the document to a memory buffer ... ";
 
+		MemBufFormatTarget *formatTarget = new MemBufFormatTarget();
+
+#if defined (XSEC_XERCES_DOMLSSERIALIZER)
+
+        // DOM L3 version as per Xerces 3.0 API
+        DOMLSSerializer   *theSerializer = ((DOMImplementationLS*)impl)->createLSSerializer();
+
+        // Get the config so we can set up pretty printing
+        DOMConfiguration *dc = theSerializer->getDomConfig();
+        dc->setParameter(XMLUni::fgDOMWRTFormatPrettyPrint, false);
+        
+        // Now create an output object to format to UTF-8
+        DOMLSOutput *theOutput = ((DOMImplementationLS*)impl)->createLSOutput();
+        Janitor<DOMLSOutput> j_theOutput(theOutput);
+        
+        theOutput->setEncoding(MAKE_UNICODE_STRING("UTF-8"));
+        theOutput->setByteStream(formatTarget);
+
+        theSerializer->write(doc,theOutput);
+#else
+
 		DOMWriter         *theSerializer = ((DOMImplementationLS*)impl)->createDOMWriter();
 
 		theSerializer->setEncoding(MAKE_UNICODE_STRING("UTF-8"));
 		if (theSerializer->canSetFeature(XMLUni::fgDOMWRTFormatPrettyPrint, false))
 			theSerializer->setFeature(XMLUni::fgDOMWRTFormatPrettyPrint, false);
 
-
-		MemBufFormatTarget *formatTarget = new MemBufFormatTarget();
-
 		theSerializer->writeNode(formatTarget, *doc);
+#endif
 
 		// Copy to a new buffer
 		len = formatTarget->getLen();
@@ -1320,7 +1628,7 @@ void unitTestCipherReference(DOMImplementation * impl) {
 		// Now create the data that is referenced
 		DOMElement * cipherVal = doc->createElement(MAKE_UNICODE_STRING("MyCipherValue"));
 		rootElem->appendChild(cipherVal);
-		cipherVal->setAttribute(MAKE_UNICODE_STRING("Id"), MAKE_UNICODE_STRING("CipherText"));
+		cipherVal->setAttributeNS(NULL, MAKE_UNICODE_STRING("Id"), MAKE_UNICODE_STRING("CipherText"));
 #if defined(XSEC_XERCES_HAS_SETIDATTRIBUTE)
 		cipherVal->setIdAttribute(MAKE_UNICODE_STRING("Id"));
 #endif
@@ -1502,6 +1810,115 @@ void unitTestElementContentEncrypt(DOMImplementation *impl, XSECCryptoKey * key,
 
 }
 
+void unitTestSmallElement(DOMImplementation *impl) {
+	
+	cerr << "Encrypt small input... ";
+
+	// Create a document
+    
+	DOMDocument * doc = createTestDoc(impl);
+	DOMElement * productNode = (DOMElement *) findNode(doc, MAKE_UNICODE_STRING("product"));
+	if (productNode == NULL) {
+
+		cerr << "Error finding product node for small input encryption test" << endl;
+		exit(1);
+
+	}
+
+	// Shrink the input text
+	DOMNode * textNode = productNode->getFirstChild();
+	textNode->setNodeValue(MAKE_UNICODE_STRING("sm"));
+
+	// Create and execute cipher
+
+	XSECProvider prov;
+	XENCCipher * cipher;
+
+	try {
+		
+		/*
+		 * Now we have a document, find the data node.
+		 */
+
+		cipher = prov.newCipher(doc);
+		cipher->setXENCNSPrefix(MAKE_UNICODE_STRING("xenc"));
+		cipher->setPrettyPrint(true);
+
+		// Set a key
+		XSECCryptoSymmetricKey * ks = 
+			XSECPlatformUtils::g_cryptoProvider->keySymmetric(XSECCryptoSymmetricKey::KEY_3DES_192);
+		ks->setKey((unsigned char *) s_keyStr, 24);
+
+		cipher->setKey(ks->clone());
+	
+		// Now encrypt!
+		cipher->encryptElementContent(productNode, ENCRYPT_3DES_CBC);
+
+		cerr << "done ... check encrypted ... ";
+
+		DOMNode * t = findNode(doc, MAKE_UNICODE_STRING("product"));
+		t = findFirstChildOfType(t, DOMNode::TEXT_NODE);
+		while (t != NULL && ! strEquals(t->getNodeValue(), "sm"))
+			t = findNextChildOfType(t, DOMNode::TEXT_NODE);
+
+		if (t != NULL) {
+
+			cerr << "no - text child still exists" << endl;
+			exit(1);
+
+		}
+		else
+			cerr << "yes" << endl;
+		
+		outputDoc(impl, doc);
+		
+		cerr << "Decrypting Element content ... ";
+
+		// OK - Now we try to decrypt
+		// Find the EncryptedData node
+		DOMNode * n = findXENCNode(doc, "EncryptedData");
+
+		XENCCipher * cipher2 = prov.newCipher(doc);
+
+		cipher2->setKey(ks);
+
+		cipher2->decryptElement(static_cast<DOMElement *>(n));
+
+		cerr << "done ... check decrypt ... ";
+		t = findNode(doc, MAKE_UNICODE_STRING("product"));
+		t = findFirstChildOfType(t, DOMNode::TEXT_NODE);
+		if (t == NULL || !strEquals(t->getNodeValue(), "sm")) {
+
+			cerr << " failed - small text did not decrypt properly" << endl;
+			exit(1);
+
+		}
+		else
+			cerr << "OK" << endl;
+
+		outputDoc(impl, doc);
+
+	}
+	catch (XSECException &e)
+	{
+		cerr << "An error occured during encryption processing\n   Message: ";
+		char * ce = XMLString::transcode(e.getMsg());
+		cerr << ce << endl;
+		delete ce;
+		exit(1);
+		
+	}	
+	catch (XSECCryptoException &e)
+	{
+		cerr << "A cryptographic error occured during encryption processing\n   Message: "
+		<< e.getMsg() << endl;
+		exit(1);
+	}
+
+	doc->release();
+
+}
+
 
 void unitTestKeyEncrypt(DOMImplementation *impl, XSECCryptoKey * k, encryptionMethod em) {
 
@@ -1607,56 +2024,92 @@ void unitTestEncrypt(DOMImplementation *impl) {
 		// Key wraps
 		cerr << "RSA key wrap... ";
 
-#if defined (HAVE_OPENSSL) && defined (HAVE_WINCAPI)
-		if (!g_useWinCAPI) {
-#endif
-
 #if defined (HAVE_OPENSSL)
-		// Load the key
-		BIO * bioMem = BIO_new(BIO_s_mem());
-		BIO_puts(bioMem, s_tstRSAPrivateKey);
-		EVP_PKEY * pk = PEM_read_bio_PrivateKey(bioMem, NULL, NULL, NULL);
+		if (!g_useWinCAPI && !g_useNSS) {
+			// Load the key
+			BIO * bioMem = BIO_new(BIO_s_mem());
+			BIO_puts(bioMem, s_tstRSAPrivateKey);
+			EVP_PKEY * pk = PEM_read_bio_PrivateKey(bioMem, NULL, NULL, NULL);
 
-		OpenSSLCryptoKeyRSA * k = new OpenSSLCryptoKeyRSA(pk);
+			OpenSSLCryptoKeyRSA * k = new OpenSSLCryptoKeyRSA(pk);
 
-		unitTestKeyEncrypt(impl, k, ENCRYPT_RSA_15);
+			unitTestKeyEncrypt(impl, k, ENCRYPT_RSA_15);
 
-		cerr << "RSA OAEP key wrap... ";
-		k = new OpenSSLCryptoKeyRSA(pk);
-		unitTestKeyEncrypt(impl, k, ENCRYPT_RSA_OAEP_MGFP1);
+			cerr << "RSA OAEP key wrap... ";
+			k = new OpenSSLCryptoKeyRSA(pk);
+			unitTestKeyEncrypt(impl, k, ENCRYPT_RSA_OAEP_MGFP1);
 
-		cerr << "RSA OAEP key wrap + params... ";
-		k = new OpenSSLCryptoKeyRSA(pk);
-		k->setOAEPparams(s_tstOAEPparams, (unsigned int) strlen((char *) s_tstOAEPparams));
+			cerr << "RSA OAEP key wrap + params... ";
+			k = new OpenSSLCryptoKeyRSA(pk);
+			k->setOAEPparams(s_tstOAEPparams, (unsigned int) strlen((char *) s_tstOAEPparams));
 
-		unitTestKeyEncrypt(impl, k, ENCRYPT_RSA_OAEP_MGFP1);
+			unitTestKeyEncrypt(impl, k, ENCRYPT_RSA_OAEP_MGFP1);
 
-		BIO_free(bioMem);
-		EVP_PKEY_free(pk);
-
-#endif
-
-#if defined (HAVE_OPENSSL) && defined (HAVE_WINCAPI)
-		} else {
+			BIO_free(bioMem);
+			EVP_PKEY_free(pk);
+		}
 #endif
 
 #if defined (HAVE_WINCAPI)
+		if (g_useWinCAPI) {
 
-		// Use the internal key
-		WinCAPICryptoProvider *cp = (WinCAPICryptoProvider *) (XSECPlatformUtils::g_cryptoProvider);
-		HCRYPTPROV p = cp->getApacheKeyStore();
-		
-		WinCAPICryptoKeyRSA * rsaKey = new WinCAPICryptoKeyRSA(p, AT_KEYEXCHANGE, true);
-		unitTestKeyEncrypt(impl, rsaKey, ENCRYPT_RSA_15);
-
-		cerr << "RSA OAEP key wrap... ";
-		rsaKey = new WinCAPICryptoKeyRSA(p, AT_KEYEXCHANGE, true);
-		unitTestKeyEncrypt(impl, rsaKey, ENCRYPT_RSA_OAEP_MGFP1);
+			// Use the internal key
+			WinCAPICryptoProvider *cp = (WinCAPICryptoProvider *) (XSECPlatformUtils::g_cryptoProvider);
+			HCRYPTPROV p = cp->getApacheKeyStore();
+			
+			WinCAPICryptoKeyRSA * rsaKey = new WinCAPICryptoKeyRSA(p, AT_KEYEXCHANGE, true);
+			unitTestKeyEncrypt(impl, rsaKey, ENCRYPT_RSA_15);
 
+			cerr << "RSA OAEP key wrap... ";
+			rsaKey = new WinCAPICryptoKeyRSA(p, AT_KEYEXCHANGE, true);
+			unitTestKeyEncrypt(impl, rsaKey, ENCRYPT_RSA_OAEP_MGFP1);
+		}
 
 #endif
 
-#if defined (HAVE_OPENSSL) && defined (HAVE_WINCAPI)
+#if defined (HAVE_NSS)
+		if (g_useNSS) {
+			// Use the internal key
+			NSSCryptoProvider *cp = (NSSCryptoProvider *) (XSECPlatformUtils::g_cryptoProvider);
+
+			// Heavily based on Mozilla example code
+			SECKEYPrivateKey *prvKey = 0;
+			SECKEYPublicKey *pubKey = 0;
+			PK11SlotInfo *slot = 0;
+			PK11RSAGenParams rsaParams;
+
+			// Use a bog standard key size
+			rsaParams.keySizeInBits = 1024;
+			rsaParams.pe = 65537;
+  
+			// We need somewhere to temporarily store a generated key
+		    slot = PK11_GetInternalKeySlot();
+			if (!slot) { 
+				cerr << "Error generating key - can't get NSS slot\n";
+				exit (1);
+			}
+
+			// Do the generate
+			prvKey = PK11_GenerateKeyPair(slot, CKM_RSA_PKCS_KEY_PAIR_GEN, &rsaParams,
+               &pubKey, PR_FALSE, PR_TRUE, 0);
+
+			if (!prvKey) {
+				if (slot)
+					PK11_FreeSlot(slot);
+				cerr << "Error generating key within NSS\n";
+				exit (1);
+			}
+
+			// Now use the key!
+			NSSCryptoKeyRSA * rsaKey = new NSSCryptoKeyRSA(pubKey, prvKey);
+			unitTestKeyEncrypt(impl, rsaKey, ENCRYPT_RSA_15);
+
+			if (slot) 
+				// Actual keys will be deleted by the provider
+				PK11_FreeSlot(slot);
+			
+			cerr << "RSA OAEP key wrap skipped - not yet supported in NSS crypto provider\n";
+			
 		}
 #endif
 
@@ -1744,7 +2197,8 @@ void unitTestEncrypt(DOMImplementation *impl) {
 #else
 		cerr << "Skipped Cipher Reference Test (requires XPath)" << endl;
 #endif
-
+		cerr << "Misc. encryption tests" << endl;
+		unitTestSmallElement(impl);
 	}
 	catch (XSECCryptoException &e)
 	{
@@ -2056,6 +2510,10 @@ void printUsage(void) {
 #if defined (HAVE_WINCAPI)  && defined (HAVE_OPENSSL)
 	cerr << "     --wincapi/-w\n";
 	cerr << "         Use Windows Crypto API for crypto functionality\n\n";
+#endif
+#if defined (HAVE_NSS)
+	cerr << "     --nss/-n\n";
+	cerr << "         Use NSS Crypto API for crypto functionality\n\n";
 #endif
 	cerr << "     --print-docs/-p\n";
 	cerr << "         Print the test documents\n\n";
@@ -2080,8 +2538,10 @@ int main(int argc, char **argv) {
 	/* We output a version number to overcome a "feature" in Microsoft's memory
 	   leak detection */
 
-	cerr << "DSIG Info (Using Apache XML-Security-C Library v" << XSEC_VERSION_MAJOR <<
-		"." << XSEC_VERSION_MEDIUM << "." << XSEC_VERSION_MINOR << ")\n";
+	cerr << "DSIG Info - Using Apache XML-Security-C Library v" << 
+        XSEC_VERSION_MAJOR <<
+		"." << XSEC_VERSION_MEDIUM << "." << XSEC_VERSION_MINOR << 
+        " (" << _XSEC_VERSION_FULL << ")\n";
 
 	// Check parameters
 	bool		doEncryptionTest = true;
@@ -2094,42 +2554,49 @@ int main(int argc, char **argv) {
 
 	while (paramCount < argc) {
 
-		if (stricmp(argv[paramCount], "--help") == 0 || stricmp(argv[paramCount], "-h") == 0) {
+		if (_stricmp(argv[paramCount], "--help") == 0 || _stricmp(argv[paramCount], "-h") == 0) {
 			printUsage();
 			exit(0);
 		}
-		else if (stricmp(argv[paramCount], "--print-docs") == 0 || stricmp(argv[paramCount], "-p") == 0) {
+		else if (_stricmp(argv[paramCount], "--print-docs") == 0 || _stricmp(argv[paramCount], "-p") == 0) {
 			g_printDocs = true;
 			paramCount++;
 		}
 #if defined(HAVE_WINCAPI) && defined(HAVE_OPENSSL)
-		else if (stricmp(argv[paramCount], "--wincapi") == 0 || stricmp(argv[paramCount], "-w") == 0) {
+		else if (_stricmp(argv[paramCount], "--wincapi") == 0 || _stricmp(argv[paramCount], "-w") == 0) {
 			g_useWinCAPI = true;
 			paramCount++;
 		}
 #endif
-		else if (stricmp(argv[paramCount], "--signature-only") == 0 || stricmp(argv[paramCount], "-s") == 0) {
+#if defined(HAVE_NSS)
+		else if (stricmp(argv[paramCount], "--nss") == 0 || stricmp(argv[paramCount], "-n") == 0) {
+			g_useNSS = true;
+			paramCount++;
+		}
+#endif
+
+		else if (_stricmp(argv[paramCount], "--signature-only") == 0 || _stricmp(argv[paramCount], "-s") == 0) {
 			doEncryptionTest = false;
 			doEncryptionUnitTests = false;
 			doSignatureUnitTests = false;
 			doXKMSTest = false;
 			paramCount++;
 		}
-		else if (stricmp(argv[paramCount], "--encryption-only") == 0 || stricmp(argv[paramCount], "-e") == 0) {
+		else if (_stricmp(argv[paramCount], "--encryption-only") == 0 || _stricmp(argv[paramCount], "-e") == 0) {
 			doSignatureTest = false;
 			doEncryptionUnitTests = false;
 			doSignatureUnitTests = false;
 			doXKMSTest = false;
 			paramCount++;
 		}
-		else if (stricmp(argv[paramCount], "--encryption-unit-only") == 0 || stricmp(argv[paramCount], "-u") == 0) {
+		else if (_stricmp(argv[paramCount], "--encryption-unit-only") == 0 || _stricmp(argv[paramCount], "-u") == 0) {
 			doEncryptionTest = false;
 			doSignatureTest = false;
 			doSignatureUnitTests = false;
 			doXKMSTest = false;
 			paramCount++;
 		}
-		else if (stricmp(argv[paramCount], "--signature-unit-only") == 0 || stricmp(argv[paramCount], "-t") == 0) {
+		else if (_stricmp(argv[paramCount], "--signature-unit-only") == 0 || _stricmp(argv[paramCount], "-t") == 0) {
 			doEncryptionTest = false;
 			doSignatureTest = false;
 			doEncryptionUnitTests = false;
@@ -2183,6 +2650,15 @@ int main(int argc, char **argv) {
 			XSECPlatformUtils::SetCryptoProvider(cp);
 		}
 #endif
+#if defined (HAVE_NSS)
+		if (g_useNSS) {
+			// Setup for NSS Crypt API
+			NSSCryptoProvider * cp;
+			// First set windows as the crypto provider
+			cp = new NSSCryptoProvider();
+			XSECPlatformUtils::SetCryptoProvider(cp);
+		}
+#endif
 
 
 	}
