@@ -20,15 +20,14 @@
  * TXFMConcatChain := Takes multiple input chains and then provides
  *					  BYTE_STREAM output for each chain in order.
  *
- * $Id: TXFMConcatChains.cpp 351214 2005-02-03 13:58:14Z milan $
+ * $Id: TXFMConcatChains.cpp 575861 2007-09-15 02:57:15Z scantor $
  *
  */
 
 #include <xsec/framework/XSECDefs.hpp>
 
-#include "TXFMConcatChains.hpp"
-
 #include <xsec/transformers/TXFMChain.hpp>
+#include <xsec/transformers/TXFMConcatChains.hpp>
 #include <xsec/framework/XSECError.hpp>
 
 XERCES_CPP_NAMESPACE_USE
