@@ -21,15 +21,14 @@
  *                         HTTP wrapper for testing the client code.
  *
  *
- * $Id: XSECSOAPRequestorSimple.cpp 450286 2006-09-27 01:47:51Z blautenb $
+ * $Id: XSECSOAPRequestorSimple.cpp 575867 2007-09-15 03:16:59Z scantor $
  *
  */
 
-#include "XSECSOAPRequestorSimple.hpp"
-
 #include <xsec/framework/XSECError.hpp>
 #include <xsec/utils/XSECSafeBuffer.hpp>
 #include <xsec/utils/XSECDOMUtils.hpp>
+#include <xsec/utils/XSECSOAPRequestorSimple.hpp>
 #include <xsec/xkms/XKMSConstants.hpp>
 
 #include <stdio.h>
