@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECSafeBuffer.cpp 351214 2005-02-03 13:58:14Z milan $
+ * $Id: XSECSafeBuffer.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -542,7 +542,7 @@ safeBuffer & safeBuffer::operator << (TXFMBase * t) {
 
 // Unicode Functions
 
-const XMLCh * safeBuffer::sbStrToXMLCh(void) {
+const XMLCh * safeBuffer::sbStrToXMLCh(void) const {
 
 	checkBufferType(BUFFER_CHAR);
 	if (mp_XMLCh != NULL)
