@@ -25,7 +25,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECBinHTTPURIInputStream.cpp 351214 2005-02-03 13:58:14Z milan $
+ * $Id: XSECBinHTTPURIInputStream.cpp 575862 2007-09-15 03:02:33Z scantor $
  *
  * $Log$
  * Revision 1.8  2005/02/03 13:55:08  milan
@@ -67,8 +67,8 @@
 #include <netdb.h>
 #include <errno.h>
 
-#include "XSECBinHTTPURIInputStream.hpp"
 #include <xsec/framework/XSECError.hpp>
+#include <xsec/utils/unixutils/XSECBinHTTPURIInputStream.hpp>
 
 #include <xercesc/util/XMLNetAccessor.hpp>
 #include <xercesc/util/XMLString.hpp>
