@@ -25,7 +25,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECURIResolverGenericUnix.cpp 351214 2005-02-03 13:58:14Z milan $
+ * $Id: XSECURIResolverGenericUnix.cpp 575862 2007-09-15 03:02:33Z scantor $
  *
  * $Log$
  * Revision 1.11  2005/02/03 13:55:08  milan
@@ -64,7 +64,7 @@
  *
  */
 
-#include "XSECURIResolverGenericUnix.hpp"
+#include <xsec/utils/unixutils/XSECURIResolverGenericUnix.hpp>
 
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLUri.hpp>
