@@ -25,7 +25,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECURIResolverGenericWin32.cpp 351358 2005-05-29 00:06:55Z blautenb $
+ * $Id: XSECURIResolverGenericWin32.cpp 575862 2007-09-15 03:02:33Z scantor $
  *
  * $Log$
  * Revision 1.12  2005/05/29 00:06:55  blautenb
@@ -67,7 +67,7 @@
  *
  */
 
-#include "XSECURIResolverGenericWin32.hpp"
+#include <xsec/utils/winutils/XSECURIResolverGenericWin32.hpp>
 
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLUri.hpp>
