@@ -20,7 +20,7 @@
  * XSECAlgorithmHandlerDefault := Interface class to define handling of
  *								  default encryption algorithms
  *
- * $Id: XENCAlgorithmHandlerDefault.cpp,v 1.13 2005/02/26 03:17:08 blautenb Exp $
+ * $Id: XENCAlgorithmHandlerDefault.cpp 422122 2006-07-15 00:58:21Z blautenb $
  *
  */
 
@@ -925,7 +925,7 @@ bool XENCAlgorithmHandlerDefault::encryptToSafeBuffer(
 
 XSECCryptoKey * XENCAlgorithmHandlerDefault::createKeyForURI(
 		const XMLCh * uri,
-		unsigned char * keyBuffer,
+		const unsigned char * keyBuffer,
 		unsigned int keyLen
 		) {
 
@@ -968,5 +968,51 @@ XSECAlgorithmHandler * XENCAlgorithmHandlerDefault::clone(void) const {
 
 }
 
+// --------------------------------------------------------------------------------
+//			Unsupported operations
+// --------------------------------------------------------------------------------
+
+unsigned int XENCAlgorithmHandlerDefault::signToSafeBuffer(
+		TXFMChain * inputBytes,
+		const XMLCh * URI,
+		XSECCryptoKey * key,
+		unsigned int outputLength,
+		safeBuffer & result) {
+
+	throw XSECException(XSECException::AlgorithmMapperError, 
+			"XENCAlgorithmHandlerDefault - Signature operations not supported");
+
+}
 
 
+bool XENCAlgorithmHandlerDefault::appendSignatureHashTxfm(
+		TXFMChain * inputBytes,
+		const XMLCh * URI,
+		XSECCryptoKey * key) {
+
+	throw XSECException(XSECException::AlgorithmMapperError, 
+			"XENCAlgorithmHandlerDefault - Signature operations not supported");
+
+}
+
+bool XENCAlgorithmHandlerDefault::verifyBase64Signature(
+		TXFMChain * inputBytes,
+		const XMLCh * URI,
+		const char * sig,
+		unsigned int outputLength,
+		XSECCryptoKey * key) {
+
+	throw XSECException(XSECException::AlgorithmMapperError, 
+			"XENCAlgorithmHandlerDefault - Signature operations not supported");
+
+}
+
+bool XENCAlgorithmHandlerDefault::appendHashTxfm(
+		TXFMChain * inputBytes,
+		const XMLCh * URI) {
+
+	throw XSECException(XSECException::AlgorithmMapperError, 
+			"XENCAlgorithmHandlerDefault - Hash operations not supported");
+
+}
+
