@@ -19,7 +19,7 @@
  *
  * XENCCipherImpl := Implementation of the main encryption worker class
  *
- * $Id: XENCCipherImpl.cpp,v 1.23 2005/02/26 03:17:08 blautenb Exp $
+ * $Id: XENCCipherImpl.cpp 464121 2006-10-15 05:15:59Z blautenb $
  *
  */
 
@@ -113,6 +113,7 @@ mp_keyInfoResolver(NULL) {
 	mp_env->setDSIGNSPrefix(s_ds);
 	m_keyDerived = false;
 	m_kekDerived = false;
+	m_useExcC14nSerialisation = true;
 
 }
 
@@ -228,9 +229,9 @@ DOMDocumentFragment * XENCCipherImpl::deSerialise(safeBuffer &content, DOMNode *
 	DOMDocumentFragment * result;
 
 	// Create the context to parse the document against
-	safeBuffer sb;
+	safeBuffer sb, sbt;
 	sb.sbXMLChIn(DSIGConstants::s_unicodeStrEmpty);
-	sb.sbXMLChAppendCh(chUnicodeMarker);
+	//sb.sbXMLChAppendCh(chUnicodeMarker);
 	//sb.sbXMLChCat8("<?xml version=\"1.0\" encoding=\"UTF-16\"?><");
 	sb.sbXMLChAppendCh(chOpenAngle);
 	sb.sbXMLChCat(s_tagname);
@@ -244,13 +245,13 @@ DOMDocumentFragment * XENCCipherImpl::deSerialise(safeBuffer &content, DOMNode *
 	while (wk != NULL) {
 
 		DOMNamedNodeMap * atts = wk->getAttributes();
-		int length;
+		XMLSize_t length;
 		if (atts != NULL)
 			length = atts->getLength();
 		else
 			length = 0;
 
-		for (int i = 0 ; i < length ; ++i) {
+		for (XMLSize_t i = 0 ; i < length ; ++i) {
 			DOMNode * att = atts->item(i);
 			if (strEquals(att->getNodeName(), DSIGConstants::s_unicodeStrXmlns) ||
 				(XMLString::compareNString(att->getNodeName(), DSIGConstants::s_unicodeStrXmlns, 5) &&
@@ -283,17 +284,40 @@ DOMDocumentFragment * XENCCipherImpl::deSerialise(safeBuffer &content, DOMNode *
 		wk = wk->getParentNode();
 	}
 	sb.sbXMLChAppendCh(chCloseAngle);
+	
+	char * prefix = transcodeToUTF8(sb.rawXMLChBuffer());
+	ArrayJanitor<char> j_prefix(prefix);
+
+	sbt = prefix;
+	const char * crcb = content.rawCharBuffer();
+	int offset = 0;
+	if (crcb[0] == '<' && crcb[1] == '?') {
+		// Have a PI prefix - get rid of it
+		int i = 2;
+		while (crcb[i] != '\0' && crcb[i] != '>')
+			++i;
+
+		if (crcb[i] == '>')
+			offset = i+1;
+	}
+
+	sbt.sbStrcatIn(&crcb[offset]);
 
 	// Now transform the content to UTF-8
-	sb.sbXMLChCat8(content.rawCharBuffer());
+	//sb.sbXMLChCat8(content.rawCharBuffer());
 
 	// Terminate the string
 
+	sb.sbXMLChIn(DSIGConstants::s_unicodeStrEmpty);
 	sb.sbXMLChAppendCh(chOpenAngle);
 	sb.sbXMLChAppendCh(chForwardSlash);
 	sb.sbXMLChCat(s_tagname);
 	sb.sbXMLChAppendCh(chCloseAngle);
 
+	char * trailer = transcodeToUTF8(sb.rawXMLChBuffer());
+	ArrayJanitor<char> j_trailer(trailer);
+	sbt.sbStrcatIn(trailer);
+
 	// Now we need to parse the document
 
 	XercesDOMParser * parser = new XercesDOMParser;
@@ -305,8 +329,8 @@ DOMDocumentFragment * XENCCipherImpl::deSerialise(safeBuffer &content, DOMNode *
 
 	// Create an input source
 
-	unsigned int bytes = XMLString::stringLen(sb.rawXMLChBuffer()) * sizeof(XMLCh);
-	MemBufInputSource* memIS = new MemBufInputSource ((const XMLByte*) sb.rawBuffer(), bytes, "XSECMem");
+	unsigned int bytes = XMLString::stringLen(sbt.rawCharBuffer());
+	MemBufInputSource* memIS = new MemBufInputSource ((const XMLByte*) sbt.rawBuffer(), bytes, "XSECMem");
 	Janitor<MemBufInputSource> j_memIS(memIS);
 
 	int errorCount = 0;
@@ -315,7 +339,7 @@ DOMDocumentFragment * XENCCipherImpl::deSerialise(safeBuffer &content, DOMNode *
 	parser->parse(*memIS);
     errorCount = parser->getErrorCount();
     if (errorCount > 0)
-		throw XSECException(XSECException::CipherError, "Errors occured during de-serialisation of decrypted element content");
+        throw XSECException(XSECException::CipherError, "Errors occured during de-serialisation of decrypted element content");
 
     DOMDocument * doc = parser->getDocument();
 
@@ -406,10 +430,7 @@ XSECCryptoKey * XENCCipherImpl::decryptKeyFromKeyInfoList(DSIGKeyInfoList * kil)
 	return ret;
 }
 
-
-DOMDocument * XENCCipherImpl::decryptElement(DOMElement * element) {
-
-	XSECAlgorithmHandler *handler;
+XENCEncryptedData * XENCCipherImpl::loadEncryptedData(DOMElement * element) {
 
 	// First of all load the element
 	if (mp_encryptedData != NULL)
@@ -421,6 +442,54 @@ DOMDocument * XENCCipherImpl::decryptElement(DOMElement * element) {
 	// Load
 	mp_encryptedData->load();
 
+	return mp_encryptedData;
+
+}
+
+
+DOMDocument * XENCCipherImpl::decryptElement(DOMElement * element) {
+
+	// First of all load the element
+	if (mp_encryptedData != NULL)
+		delete mp_encryptedData;
+
+	XSECnew(mp_encryptedData, 
+		XENCEncryptedDataImpl(mp_env, element));
+
+	// Load
+	mp_encryptedData->load();
+
+	return decryptElement();
+
+}
+
+DOMNode * XENCCipherImpl::decryptElementDetached(DOMElement * element) {
+
+	// First of all load the element
+	if (mp_encryptedData != NULL)
+		delete mp_encryptedData;
+
+	XSECnew(mp_encryptedData, 
+		XENCEncryptedDataImpl(mp_env, element));
+
+	// Load
+	mp_encryptedData->load();
+
+	return decryptElementDetached();
+
+}
+
+DOMNode * XENCCipherImpl::decryptElementDetached(void) {
+
+	XSECAlgorithmHandler *handler;
+
+	if (mp_encryptedData == NULL) {
+
+		throw XSECException(XSECException::CipherError, 
+			"XENCCipherImpl::decryptElement - no element loaded for decryption");
+
+	}
+
 	// Check that this is a valid type
 	const XMLCh * typeURI = mp_encryptedData->getType();
 
@@ -483,10 +552,11 @@ DOMDocument * XENCCipherImpl::decryptElement(DOMElement * element) {
 	}
 
 	safeBuffer sb("");
+	unsigned int decryptLen;
 
 	if (handler != NULL) {
 
-		handler->decryptToSafeBuffer(c, 
+		decryptLen = handler->decryptToSafeBuffer(c, 
 			mp_encryptedData->getEncryptionMethod(), 
 			mp_key,
 			mp_env->getParentDocument(),
@@ -501,10 +571,23 @@ DOMDocument * XENCCipherImpl::decryptElement(DOMElement * element) {
 			"XENCCipherImpl::decryptElement - Error retrieving a handler for algorithm");
 
 	}
-
+	
+	sb[decryptLen] = '\0';
+	
 	// Now de-serialise
+	DOMElement * element = mp_encryptedData->getElement();
 	DOMDocumentFragment * frag = deSerialise(sb, element);
 
+	return frag;
+
+}
+
+DOMDocument * XENCCipherImpl::decryptElement(void) {
+
+	// Call the worker
+	DOMElement * element = mp_encryptedData->getElement();
+	DOMDocumentFragment * frag = (DOMDocumentFragment *) decryptElementDetached();
+
 	if (frag != NULL) {
 
 		// Have something to replace current element with
@@ -975,7 +1058,7 @@ XENCEncryptedData * XENCCipherImpl::createEncryptedData(
 //			Encrypt an element
 // --------------------------------------------------------------------------------
 
-DOMDocument * XENCCipherImpl::encryptElement(DOMElement * element, 
+DOMNode * XENCCipherImpl::encryptElementDetached(DOMElement * element, 
 											 encryptionMethod em,
 											 const XMLCh * algorithmURI) {
 
@@ -1001,13 +1084,24 @@ DOMDocument * XENCCipherImpl::encryptElement(DOMElement * element,
 	c->appendTxfm(tc14n);
 
 	tc14n->activateComments();
-	tc14n->setExclusive();
+	if (m_useExcC14nSerialisation)
+		tc14n->setExclusive();
 
 	// Do the hard work
 
 	encryptTXFMChain(c, em, algorithmURI);
 
 	mp_encryptedData->setType(DSIGConstants::s_unicodeStrURIXENC_ELEMENT);
+	return mp_encryptedData->getElement();
+
+}
+
+DOMDocument * XENCCipherImpl::encryptElement(DOMElement * element, 
+											 encryptionMethod em,
+											 const XMLCh * algorithmURI) {
+
+	// Do the actual encryption work
+	encryptElementDetached(element, em, algorithmURI);
 
 	// Replace original element
 	DOMNode * p = element->getParentNode();
@@ -1026,6 +1120,7 @@ DOMDocument * XENCCipherImpl::encryptElement(DOMElement * element,
 
 }
 
+
 // --------------------------------------------------------------------------------
 //			Encrypt an element's children
 // --------------------------------------------------------------------------------
@@ -1034,6 +1129,33 @@ DOMDocument * XENCCipherImpl::encryptElementContent(
 		XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * element,
 		encryptionMethod em,
 		const XMLCh * algorithmURI) {
+	
+	// Do the work
+	encryptElementContentDetached(element, em, algorithmURI);
+
+	// Delete current children 
+	DOMNode * n = element->getFirstChild();
+	while (n != NULL) {
+
+		element->removeChild(n);
+		n->release();
+
+		n = element->getFirstChild();
+
+	}
+	
+	// Now add the EncryptedData
+	element->appendChild(mp_encryptedData->getElement());
+
+	return mp_doc;
+
+}
+
+
+DOMNode * XENCCipherImpl::encryptElementContentDetached(
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * element,
+		encryptionMethod em,
+		const XMLCh * algorithmURI) {
 
 	// Make sure we have a key before we do anything too drastic
 	if (mp_key == NULL) {
@@ -1072,7 +1194,8 @@ DOMDocument * XENCCipherImpl::encryptElementContent(
 		tc->appendTxfm(tc14n);
 
 		tc14n->activateComments();
-		tc14n->setExclusive();
+		if (m_useExcC14nSerialisation)
+			tc14n->setExclusive();
 
 		n = n->getNextSibling();
 
@@ -1082,31 +1205,31 @@ DOMDocument * XENCCipherImpl::encryptElementContent(
 
 	mp_encryptedData->setType(DSIGConstants::s_unicodeStrURIXENC_CONTENT);
 
-	// Delete current children 
-	n = element->getFirstChild();
-	while (n != NULL) {
-
-		element->removeChild(n);
-		n->release();
-
-		n = element->getFirstChild();
-
-	}
-	
-	// Now add the EncryptedData
-	element->appendChild(mp_encryptedData->getElement());
-
-	return mp_doc;
+	return mp_encryptedData->getElement();
 
 }
 
 
 
-
 // --------------------------------------------------------------------------------
 //			Pretty Print functions
 // --------------------------------------------------------------------------------
 
+void XENCCipherImpl::setExclusiveC14nSerialisation(bool flag) {
+
+	m_useExcC14nSerialisation = flag;
+}
+
+bool XENCCipherImpl::getExclusiveC14nSerialisation(void) {
+
+	return m_useExcC14nSerialisation;
+
+}
+
+// --------------------------------------------------------------------------------
+//			Exclusive C14n serialisation setting
+// --------------------------------------------------------------------------------
+
 void XENCCipherImpl::setPrettyPrint(bool flag) {
 
 	mp_env->setPrettyPrintFlag(flag);
@@ -1118,4 +1241,3 @@ bool XENCCipherImpl::getPrettyPrint(void) {
 	return mp_env->getPrettyPrintFlag();
 
 }
-
