@@ -19,7 +19,7 @@
  *
  * XKMSMessageFactory := Interface for the factory used to produce XKMS msgs
  *
- * $Id: XKMSMessageFactory.hpp,v 1.11 2005/06/04 11:30:26 blautenb Exp $
+ * $Id: XKMSMessageFactory.hpp 383302 2006-03-05 10:20:07Z blautenb $
  *
  */
 
@@ -46,6 +46,12 @@ class XKMSStatusRequest;
 class XKMSStatusResult;
 class XKMSRegisterRequest;
 class XKMSRegisterResult;
+class XKMSRevokeResult;
+class XKMSRevokeRequest;
+class XKMSRecoverResult;
+class XKMSRecoverRequest;
+class XKMSReissueResult;
+class XKMSReissueRequest;
 
 XSEC_DECLARE_XERCES_CLASS(DOMElement);
 
@@ -656,6 +662,276 @@ public:
 		XKMSResultType::ResultMinor rmin = XKMSResultType::NoneMinor,
 		const XMLCh * id = NULL) = 0;
 
+	/**
+	 * \brief Create a new \<RevokeRequest\> message.
+	 * 
+	 * Generates a new RevokeRequest message from scratch, building the DOM
+	 * as it goes.
+	 *
+	 * @param service URI
+	 * @param doc Document to create the DOM structure within.  The caller
+	 * will need to embed the DOM structure at the appropriate place in the
+	 * document (using a call to getElement to find the top level element)
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+	 * @returns the new XKMSRevokeRequest structure
+	 */
+
+	virtual XKMSRevokeRequest * createRevokeRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		const XMLCh * id = NULL) = 0;
+		
+	/**
+	 * \brief Create a new \<RevokeRequest\> message and surrounding document
+	 * 
+	 * Generates a new RevokeRequest message from scratch, building the DOM
+	 * as it goes.
+	 *
+	 * @param service URI
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+	 * @returns the new XKMSRevokeRequest structure
+	 * @note Like all the xsec library functions, the document is owned by
+	 * the calling application.  Deleting the RevokeRequest object will not
+	 * delete the DOM document as well.
+	 */
+
+	virtual XKMSRevokeRequest * createRevokeRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		const XMLCh * id = NULL) = 0;
+
+	/**
+	 * \brief Create a new \<RevokeResult\> message.
+	 * 
+	 * Generates a new RevokeResult message from scratch, building the DOM
+	 * as it goes.  The response will be based on a input RevokeRequest message
+	 * which is used to provide Id etc.
+	 *
+	 * @param request Request to base response on
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+     * @param rmaj Major result code
+     * @param rmin Minor result code
+	 * @returns the new XKMSRevokeResponse structure
+	 */
+
+	virtual XKMSRevokeResult * createRevokeResult(
+		XKMSRevokeRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin = XKMSResultType::NoneMinor,
+		const XMLCh * id = NULL) = 0;
+
+	/**
+	 * \brief Create a new \<RevokeResult\> message and surrounding document
+	 * 
+	 * Generates a new RevokeResult message from scratch, building the DOM
+	 * as it goes.  The response will be based on a input RevokeRequest message
+	 * which is used to provide Id etc.
+	 *
+	 * @param request Request to base response on
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+     * @param rmaj Major result code
+     * @param rmin Minor result code
+	 * @returns the new XKMSRevokeResponse structure
+	 * @note Like all the xsec library functions, the document is owned by
+	 * the calling application.  Deleting the RevokeRequest object will not
+	 * delete the DOM document as well.
+	 */
+
+	virtual XKMSRevokeResult * createRevokeResult(
+		XKMSRevokeRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin = XKMSResultType::NoneMinor,
+		const XMLCh * id = NULL) = 0;
+
+	/**
+	 * \brief Create a new \<RecoverRequest\> message.
+	 * 
+	 * Generates a new RecoverRequest message from scratch, building the DOM
+	 * as it goes.
+	 *
+	 * @param service URI
+	 * @param doc Document to create the DOM structure within.  The caller
+	 * will need to embed the DOM structure at the appropriate place in the
+	 * document (using a call to getElement to find the top level element)
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+	 * @returns the new XKMSRecoverRequest structure
+	 */
+
+	virtual XKMSRecoverRequest * createRecoverRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		const XMLCh * id = NULL) = 0;
+		
+	/**
+	 * \brief Create a new \<RecoverRequest\> message and surrounding document
+	 * 
+	 * Generates a new RecoverRequest message from scratch, building the DOM
+	 * as it goes.
+	 *
+	 * @param service URI
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+	 * @returns the new XKMSRecoverRequest structure
+	 * @note Like all the xsec library functions, the document is owned by
+	 * the calling application.  Deleting the RecoverRequest object will not
+	 * delete the DOM document as well.
+	 */
+
+	virtual XKMSRecoverRequest * createRecoverRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		const XMLCh * id = NULL) = 0;
+
+	/**
+	 * \brief Create a new \<RecoverResult\> message.
+	 * 
+	 * Generates a new RecoverResult message from scratch, building the DOM
+	 * as it goes.  The response will be based on a input RecoverRequest message
+	 * which is used to provide Id etc.
+	 *
+	 * @param request Request to base response on
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+     * @param rmaj Major result code
+     * @param rmin Minor result code
+	 * @returns the new XKMSRecoverResponse structure
+	 */
+
+	virtual XKMSRecoverResult * createRecoverResult(
+		XKMSRecoverRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin = XKMSResultType::NoneMinor,
+		const XMLCh * id = NULL) = 0;
+
+	/**
+	 * \brief Create a new \<RecoverResult\> message and surrounding document
+	 * 
+	 * Generates a new RecoverResult message from scratch, building the DOM
+	 * as it goes.  The response will be based on a input RecoverRequest message
+	 * which is used to provide Id etc.
+	 *
+	 * @param request Request to base response on
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+     * @param rmaj Major result code
+     * @param rmin Minor result code
+	 * @returns the new XKMSRecoverResponse structure
+	 * @note Like all the xsec library functions, the document is owned by
+	 * the calling application.  Deleting the RecoverRequest object will not
+	 * delete the DOM document as well.
+	 */
+
+	virtual XKMSRecoverResult * createRecoverResult(
+		XKMSRecoverRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin = XKMSResultType::NoneMinor,
+		const XMLCh * id = NULL) = 0;
+
+	/**
+	 * \brief Create a new \<ReissueRequest\> message.
+	 * 
+	 * Generates a new ReissueRequest message from scratch, building the DOM
+	 * as it goes.
+	 *
+	 * @param service URI
+	 * @param doc Document to create the DOM structure within.  The caller
+	 * will need to embed the DOM structure at the appropriate place in the
+	 * document (using a call to getElement to find the top level element)
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+	 * @returns the new XKMSReissueRequest structure
+	 */
+
+	virtual XKMSReissueRequest * createReissueRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		const XMLCh * id = NULL) = 0;
+		
+	/**
+	 * \brief Create a new \<ReissueRequest\> message and surrounding document
+	 * 
+	 * Generates a new ReissueRequest message from scratch, building the DOM
+	 * as it goes.
+	 *
+	 * @param service URI
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+	 * @returns the new XKMSReissueRequest structure
+	 * @note Like all the xsec library functions, the document is owned by
+	 * the calling application.  Deleting the ReissueRequest object will not
+	 * delete the DOM document as well.
+	 */
+
+	virtual XKMSReissueRequest * createReissueRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		const XMLCh * id = NULL) = 0;
+
+	/**
+	 * \brief Create a new \<ReissueResult\> message.
+	 * 
+	 * Generates a new ReissueResult message from scratch, building the DOM
+	 * as it goes.  The response will be based on a input ReissueRequest message
+	 * which is used to provide Id etc.
+	 *
+	 * @param request Request to base response on
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+     * @param rmaj Major result code
+     * @param rmin Minor result code
+	 * @returns the new XKMSReissueResponse structure
+	 */
+
+	virtual XKMSReissueResult * createReissueResult(
+		XKMSReissueRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin = XKMSResultType::NoneMinor,
+		const XMLCh * id = NULL) = 0;
+
+	/**
+	 * \brief Create a new \<ReissueResult\> message and surrounding document
+	 * 
+	 * Generates a new ReissueResult message from scratch, building the DOM
+	 * as it goes.  The response will be based on a input ReissueRequest message
+	 * which is used to provide Id etc.
+	 *
+	 * @param request Request to base response on
+	 * @param doc Will be used to return the newly created document element in.
+	 * @param id Value to set in the Id field.  If NULL, the library will
+	 * generate a new Unique Id value.
+     * @param rmaj Major result code
+     * @param rmin Minor result code
+	 * @returns the new XKMSReissueResponse structure
+	 * @note Like all the xsec library functions, the document is owned by
+	 * the calling application.  Deleting the ReissueRequest object will not
+	 * delete the DOM document as well.
+	 */
+
+	virtual XKMSReissueResult * createReissueResult(
+		XKMSReissueRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin = XKMSResultType::NoneMinor,
+		const XMLCh * id = NULL) = 0;
+
 	//@}
 
 	/** @name Environment Manipulation Functions */
